@@ -1,3 +1,13 @@
+/*! \file
+    \ingroup CCENERGY
+    \brief Enter brief description of file here 
+*/
+
+#ifndef _psi_src_bin_ccenergy_local_h
+#define _psi_src_bin_ccenergy_local_h
+
+namespace psi { namespace ccenergy {
+
 struct Local {
   int natom;
   int nso;
@@ -23,3 +33,7 @@ struct Local {
   char *freeze_core;
   char *pairdef;
 };
+
+}} // namespace psi::ccenergy
+
+#endif // _psi_src_bin_ccenergy_local_h
