@@ -1,3 +1,13 @@
+/*! \file
+    \ingroup CCENERGY
+    \brief Enter brief description of file here 
+*/
+
+#ifndef _psi_src_bin_ccenergy_moinfo_h
+#define _psi_src_bin_ccenergy_moinfo_h
+
+namespace psi { namespace ccenergy {
+
 struct MOInfo {
   int nirreps;           /* no. of irreducible representations */
   int nmo;               /* no. of molecular orbitals */
@@ -5,9 +15,9 @@ struct MOInfo {
   int nao;               /* no. of atomic orbitals */
   int iopen;             /* 0=closed shell; >0=open shell */
   int phase;             /* Boolean for consistency of orbital phases */
-  int aobasis;
+  int *sopi;             /* no. of SOs per irrep (only used in AO-based algorithm) */
+  int *sosym;            /* SO symmetry (Pitzer) */
   int *orbspi;           /* no. of MOs per irrep */
-  int *orbsym;           /* orbital symmetry (Pitzer/SO) */
   int *clsdpi;           /* no. of closed-shells per irrep excl. frdocc */
   int *openpi;           /* no. of open-shells per irrep */
   int *uoccpi;           /* no. of unoccupied orbitals per irr. ex. fruocc */
@@ -59,9 +69,17 @@ struct MOInfo {
   double conv;           /* Current convergence level */
   double enuc;           /* Nuclear repulsion energy */
   double emp2;           /* MP2 energy */
+  double emp2_ss;        /* Same-spin MP2 correlation energy*/
+  double emp2_os;        /* Opposite-spin MP2 correlation energy*/
+  double escsmp2_ss;     /* Scaled-SS MP2 correlation energy*/
+  double escsmp2_os;     /* Scaled-OS MP2 correlation energy*/
   double escf;           /* SCF energy (from chkpt) */
   double eref;           /* Reference energy (file100) */
-  double ecc;            /* Current coupled cluster energy */
+  double ecc;            /* Current coupled cluster correlation energy */
+  double ecc_ss;	 /* Same-spin coupled cluster correlation energy*/
+  double ecc_os;         /* Opposite-spin coupled cluster energy*/
+  double escscc_ss;      /* Scaled-SS coupled cluster correlation energy*/
+  double escscc_os;      /* Scaled-OS coupled cluster energy*/
   double t1diag;         /* Standard open- or closed-shell T1 diagnostic */
   double d1diag;         /* Janssen and Nielsen's D1 Diagnostic */
   double new_d1diag;     /* Lee's modified D1 Diagnostic */
@@ -69,3 +87,7 @@ struct MOInfo {
   double ***Ca;          /* UHF alpha virtual orbital transformation matrix (for AO-basis B terms) */
   double ***Cb;          /* UHF beta virtual orbital transformation matrix (for AO-basis B terms) */
 };
+
+}} // namespace psi::ccenergy
+
+#endif //  _psi_src_bin_ccenergy_moinfo_h
