@@ -1,3 +1,10 @@
+/*! \file
+    \ingroup CCEOM
+    \brief Enter brief description of file here 
+*/
+
+namespace psi { namespace cceom {
+
 struct Local {
   int natom;
   int nso;
@@ -23,3 +30,5 @@ struct Local {
   int filter_singles;
   double weak_pair_energy;
 };
+
+}} // namespace psi::cceom
