@@ -1,12 +1,19 @@
+/*! \file
+    \ingroup CCEOM
+    \brief Enter brief description of file here 
+*/
+
+namespace psi { namespace cceom {
+
 struct MOInfo {
   int nirreps;           /* no. of irreducible representations */
   int nmo;               /* no. of molecular orbitals */
   int nso;               /* no. of symmetry orbitals */
   int iopen;             /* 0=closed shell; >0=open shell */
   int phase;             /* Boolean for consistency of orbital phases */
-  int aobasis;
+  int *sopi;             /* no. of SOs per irrep */
+  int *sosym;            /* orbital symmetry (Pitzer/SO) */
   int *orbspi;           /* no. of MOs per irrep */
-  int *orbsym;           /* orbital symmetry (Pitzer/SO) */
   int *clsdpi;           /* no. of closed-shells per irrep excl. frdocc */
   int *openpi;           /* no. of open-shells per irrep */
   int *uoccpi;           /* no. of unoccupied orbitals per irr. ex. fruocc */
@@ -45,3 +52,5 @@ struct MOInfo {
   double ***Ca;          /* UHF alpha virtual orbital transformation matrix (for AO-basis B terms) */
   double ***Cb;          /* UHF beta virtual orbital transformation matrix (for AO-basis B terms) */
 };
+
+}} // namespace psi::cceom
