@@ -1,3 +1,10 @@
+/*! \file
+    \ingroup CCEOM
+    \brief Enter brief description of file here 
+*/
+
+namespace psi { namespace cceom {
+
 /* Input parameters for ccenergy */
 struct Params {
   long int memory;
@@ -12,6 +19,7 @@ struct Params {
   int full_matrix; /* include reference rows/cols in diagonalization */
   char *abcd;
   int t3_Ws_incore;
+  int nthreads;
 };
 
 struct Eom_params {
@@ -19,6 +27,8 @@ struct Eom_params {
   int vectors_per_root;
   int *states_per_irrep;
   int *cs_per_irrep;
+  double *state_energies;
+  int number_of_states;
   double eval_tol;
   double eval_tol_SS;
   double residual_tol;
@@ -36,7 +46,7 @@ struct Eom_params {
   int rhf_triplets;
   int mult;
   int follow_root;
-  int restart_vectors_per_root;
+  int collapse_with_last;
   int skip_diagSS;
   int vectors_cc3;
   int restart_eom_cc3;
@@ -47,3 +57,5 @@ struct Eom_params {
   int L_irr;
 };
 
+
+}} // namespace psi::cceom
