@@ -1,8 +1,11 @@
+/*! \file
+    \ingroup CCEOM
+    \brief Enter brief description of file here 
+*/
 #include <ccfiles.h>
 #include <libdpd/dpd.h>
-#include "MOInfo.h"
-#include "Params.h"
-#include "Local.h"
+
+namespace psi { namespace cceom {
 
 /* Global variables */
 #ifdef EXTERN
@@ -12,19 +15,23 @@
 #define EXTERN
 #endif
 
-/* #define EOM_DEBUG (1) */
+EXTERN void check_sum(char *term_lbl, int index, int irrep);
+
+// #define EOM_DEBUG (0)
 #define TIME_CCEOM (1)
 
 #define H_IRR (0)
 #define MAX(I,J) ((I>J) ? I : J)
 #define MIN(I,J) ((I<J) ? I : J)
 
+extern "C" {
 EXTERN FILE *infile, *outfile;
 EXTERN char *psi_file_prefix;
+}
 EXTERN struct MOInfo moinfo;
 EXTERN struct Params params;
 EXTERN struct Eom_params eom_params;
 EXTERN struct Local local;
 EXTERN int ***dpd_dp;
 
-
+}} // namespace psi::cceom
