@@ -1,3 +1,10 @@
+/*! \file
+    \ingroup CCLAMBDA
+    \brief Enter brief description of file here 
+*/
+
+namespace psi { namespace cclambda {
+
 struct MOInfo {
   int nirreps;        /* no. of irreducible representations */
   int nmo;            /* no. of molecular orbitals */
@@ -5,8 +12,9 @@ struct MOInfo {
   int nao;
   int iopen;          /* 0=closed shell; >0=open shell */
   int phase;          /* Boolean for consistency of orbital phases */
+  int *sopi;          /* no. of SOs per irrep */
+  int *sosym;         /* SO symmetry (Pitzer) */
   int *orbspi;        /* no. of MOs per irrep */
-  int *orbsym;        /* orbital symmetry (Pitzer/SO) */
   int *clsdpi;        /* no. of closed-shells per irrep excl. frdocc */
   int *openpi;        /* no. of open-shells per irrep */
   int *uoccpi;        /* no. of unoccupied orbitals per irrep excl. fruocc */
@@ -44,3 +52,5 @@ struct MOInfo {
   double ***Ca;       /* UHF alpha virtual orbital transformation matr5ix (for AO-basis B terms) */
   double ***Cb;       /* UHF beta virtual orbital transformation matr5ix (for AO-basis B terms) */
 };
+
+}} // namespace psi::cclambda
