@@ -1,3 +1,10 @@
+/*! \file
+    \ingroup CCRESPONSE
+    \brief Enter brief description of file here 
+*/
+
+namespace psi { namespace ccresponse {
+
 struct MOInfo {
   int nirreps;        /* no. of irreducible representations */
   int nmo;            /* no. of molecular orbitals */
@@ -8,6 +15,7 @@ struct MOInfo {
   int noei_ao;        /* no. of elements in AOxAO lower triangle */
   int nactive;        /* no. of active MO's */
   int nfzc;           /* no. of frozen core orbitals */
+  int *sopi;          /* no. of SOs per irrep */
   int *orbspi;        /* no. of MOs per irrep */
   int *clsdpi;        /* no. of closed-shells per irrep  */
   int *openpi;        /* no. of open-shells per irrep */
@@ -74,3 +82,5 @@ struct MOInfo {
   double *zvals;      /* atomic zvals */
   double ***C;        /* Virtual orbital transformation matrix */
 };
+
+}} // namespace psi::ccresponse
