@@ -1,3 +1,10 @@
+/*! \file
+    \ingroup CCRESPONSE
+    \brief Enter brief description of file here 
+*/
+
+namespace psi { namespace ccresponse {
+
 struct Params {
   int print;             /* Output level control */
   long int memory;       /* Memory available (in bytes) */
@@ -19,3 +26,5 @@ struct Params {
   int num_amps;
   int sekino;  /* Sekino-Bartlett size-extensive models */
 };
+
+}} // namespace psi::ccresponse
