@@ -1,3 +1,12 @@
+/*! \file
+    \ingroup CCSORT
+    \brief Enter brief description of file here 
+*/
+
+/*! \defgroup CCSORT ccsort: Sort integrals for Coupled-Cluster Modules */
+
+namespace psi { namespace ccsort {
+
 struct Local {
   int natom;
   int nso;
@@ -27,3 +36,5 @@ struct Local {
   char *freeze_core;
   char *pairdef;
 };
+
+}} // namespace psi::ccsort
