@@ -1,3 +1,7 @@
+/*! \file
+    \ingroup CINTS
+    \brief Enter brief description of file here 
+*/
 
 #include "giao_oe_deriv.h"
 #include "giao_te_deriv.h"
@@ -5,7 +9,8 @@
 #define DO_OEI 1
 #define DO_TEI 1
 
-extern "C" void giao_deriv()
+namespace psi { namespace CINTS {
+void giao_deriv()
 {
 #if DO_OEI
   giao_oe_deriv();
@@ -15,3 +20,4 @@ extern "C" void giao_deriv()
 #endif
 }
 
+};};
