@@ -1,3 +1,10 @@
+#ifndef _psi_src_bin_cints_defines_h
+#define _psi_src_bin_cints_defines_h
+
+/*! \file
+    \ingroup CINTS
+    \brief Enter brief description of file here 
+*/
 /*---------------------
   Customizable values
  ---------------------*/
@@ -75,6 +82,8 @@
 			    3 - [r12,T2]
 			    */
 
+#define MkPT2_USE_IWL 1 /* How the MkPT2 routine dumps integrals to disk */
+#define MkPT2_TEST 0    /* Whether to test the MkPT2 integrals by printing them on writing to IWL and reading them back in */
 /*----------
   DFT cutoffs
   ----------*/
@@ -89,4 +98,4 @@
 				matrix 
 			     */
 
-
+#endif
