@@ -1,4 +1,8 @@
-/* $Id: common.h 2969 2005-11-10 16:37:50Z evaleev $ */
+/*! \file
+    \ingroup CSCF
+    \brief Enter brief description of file here 
+*/
+/* $Id: common.h 4032 2008-11-24 17:50:44Z crawdad $ */
 /* $Log$
  * Revision 1.17  2005/11/10 16:37:50  evaleev
  * Added CHECK_MO_ORTHONORMALITY input keyword. Useful for debugging.
@@ -150,9 +154,15 @@
  * -Ed
  * */
 
+#ifndef _psi_bin_cscf_common_h_
+#define _psi_bin_cscf_common_h_
+
 #include <libciomr/libciomr.h>
 #include <libchkpt/chkpt.h>
 #include <libpsio/psio.h>
+#include <libipv1/ip_lib.h>
+#include <string>
+#include <vector>
 
 #define MAX_BASIS 4096
 #define MAXIOFF 4096
@@ -168,8 +178,14 @@
 # define EXTERN
 #endif
 
-EXTERN FILE *infile, *outfile, *JK,*gmat,*diis_out;
-EXTERN char **psi_file_prefix;
+extern "C" {
+  EXTERN FILE *infile, *outfile;
+  EXTERN char *psi_file_prefix;
+}
+
+namespace psi { namespace cscf {
+
+EXTERN FILE *JK,*gmat,*diis_out;
 
 EXTERN double dampsv;           /* scale factor in diis */
 EXTERN double repnuc;           /* nuclear repulsion */
@@ -180,6 +196,7 @@ EXTERN double corr_energy;      /* KS DFT correlation energy */
 EXTERN double coulomb_energy;   /* Coulomb energy */
 EXTERN double den_trace;        /* KS DFT trace of the density */
 EXTERN double lshift;           /* levelshift */
+EXTERN int    stop_lshift;      /* cycle to turn off levelshift */
 EXTERN double diiser;           /* max off-diag. element in MO fock mat. */
 EXTERN double save_ci1,save_ci2; /* ci coefficients for tcscf */
 EXTERN double dampd;
@@ -191,6 +208,9 @@ EXTERN int diisflg;             /* 0 for diis, 1 disables diis */
 EXTERN int scf_conv;               /* dmat convg. criterion */
 EXTERN int iopen;               /* 0 for closed, 1 for open, 2 for twocon */
 EXTERN int inflg;               /* 0 default, 1 use old guess, 2 use core H */
+EXTERN int hcore_guess;         /* 0 -- obtain using diagonalization of H(core) in orthogonalized SO,
+                                   1 -- diagonalize H(core) in nonorthogonal SO (this hack is borrowed from MPQC's OneBodyWavefunction::hcore_guess()
+                                 */
 EXTERN int print;               /* print flag */
 EXTERN int fock_typ;            /* 0 for default, 1 for simpler op sh fock m */
 EXTERN int ndiis;               /* # of error matrices to keep in diis */
@@ -200,6 +220,7 @@ EXTERN int use_iwl;             /* use IWL format */
 EXTERN int delete_ints;         /* delete ints? */
 EXTERN int delete_1e;           /* delete one-electron ints? */
 EXTERN int delete_2e;           /* delete two-electron ints? */
+EXTERN int reset_occ;           /* reset occupations? */
 
 EXTERN int multp;		/* multiplicity of the molecule */
 EXTERN int mflag;               /* 1 if multp specified */
@@ -237,7 +258,6 @@ EXTERN int special;             /* 1 if OPENTYPE=special */
 EXTERN int twocon;              /* 1 if tcscf */
 EXTERN int ksdft;               /* 1 if Kohn-Sham DFT */
 EXTERN int mixing;              /* 1 if mixing for UHF, default is 0 */
-EXTERN PSI_FPTR pos34;               /* pointer to location in file34 */
 EXTERN int cscf_nint;                /* number of pki ints in present batch */
 EXTERN int opshl1,opshl2;
 EXTERN int opblk1,opblk2;
@@ -256,6 +276,9 @@ EXTERN double *zvals;		/* array for nuclear charges */
 EXTERN int *symm_tot;           /* array containing the orbital symmetries in order of energy */
 EXTERN double *ener_tot;        /* array containing the orbital energies in order */
 
+EXTERN std::string reorder;     /* valid values are "BEFORE" and "AFTER" */
+EXTERN std::vector<int> moorder; /* maps MOs to the new order */
+
 EXTERN int *i10;  
 
 EXTERN union psi_buffer {
@@ -316,7 +339,7 @@ EXTERN struct symm {
 /* STB - 10/11/99 - structure added to handle spin */
 EXTERN struct spin {
     struct symm *scf_spin;
-    char *spinlabel;
+    const char *spinlabel;
 } *spin_info;
 
 /* TDC(6/19/96) - Added flag for success or failure of phase checking
@@ -333,3 +356,46 @@ EXTERN int tight_ints, ok_ints,    /*keeps track of acccuracy being used*/
                                      switched*/
 EXTERN double delta;               /*just another density convergence
                                      variable*/
+
+void occ_init();
+void init_scf();
+void init_scf2();
+void init_uhf();
+void scf_input(ip_value_t *);
+void rdone_iwl();
+void form_vec();
+void shalf();
+void guess();
+void schmit(int);
+void schmit_uhf(int);
+void print_mos(const char* spincase, const struct symm* scfinfo);
+void print_mos_aobasis(const char* spincase, const struct symm* scfinfo);
+void print_mos_cartaobasis(const char* spincase, const struct symm* scfinfo);
+void dmat();
+void dmatuhf();
+void cmatsplit();
+void rdtwo();
+void formg_direct();
+void scf_iter();
+void scf_iter_2();
+void uhf_iter();
+void cleanup();
+void sortev();
+void rotate_vector();
+void sdot(double** a, double** b, int n, double* value);
+void errchk(int errcod, const char* token);
+int ecalc(double incr);
+void occ_calc();
+void diis(double** scr1, double** scr2, double** scr3, double* c1, double* c2, double cim, int newci);
+void formg_open();
+void formg_closed();
+void dmat_2(int opblk);
+void formg_two(int iju, int* optest);
+void occ_read();
+void occ_out(void);
+void diis_uhf(void);
+void orb_mix(void);
+
+}} // namespace psi::cscf
+
+#endif // header guard
