@@ -1,21 +1,21 @@
-/*
-**
-**  DBOC: Driver program for computing the Diagonal Born-Oppenheimer Correction
-**
+/*! \defgroup DBOC dboc: Diagonal Born-Oppenheimer Correction */
+
+/*! \file
+    \ingroup DBOC
+    \brief Driver program for computing the Diagonal 
+      Born-Oppenheimer Correction
 */
 
 #include <stdexcept>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-extern "C" {
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 #include <libipv1/ip_lib.h>
 #include <libciomr/libciomr.h>
 #include <libchkpt/chkpt.h>
 #include <libpsio/psio.h>
 #include <libqt/slaterdset.h>
 #include <psifiles.h>
-}
 #include <libbasis/basisset.h>
 #include <libbasis/overlap.h>
 #include <masses.h>
@@ -30,6 +30,14 @@ extern "C" {
   extern int setenv(const char *, const char *, int);
 #endif
 
+extern "C" {
+FILE *infile, *outfile;
+char *psi_file_prefix;
+}
+extern "C" const char *gprgid();
+
+namespace psi { namespace dboc {
+
 /* Function prototypes */
 static void init_io(int argc, char *argv[]);
 static void exit_io();
@@ -40,21 +48,18 @@ static double eval_dboc();
 extern void print_intro();
 extern void print_params();
 extern void print_geom();
-extern "C" char *gprgid();
 extern void setup_geoms();
 extern double eval_derwfn_overlap(bool symm_coord);
 extern void read_moinfo();
 
 /*--- Global structures ---*/
-FILE *infile, *outfile;
-char *psi_file_prefix;
 Molecule_t Molecule;
 MOInfo_t MOInfo;
 Params_t Params;
 
 BasisSet* BasisSets[MAX_NUM_DISP];  // Array of pointers to basis set objects with current coordinate displaced by +delta, -delta, +2delta, and -2delta, respectively
 HFWavefunction* HFVectors[MAX_NUM_DISP];  // Array of pointers to HF wavefunctions for displacements by +delta, -delta, +2delta, and -2delta, respectively
-char* CI_Vector_Labels[MAX_NUM_DISP] = {
+const char* CI_Vector_Labels[MAX_NUM_DISP] = {
   "R0-delta CI Vector",
   "R0+delta CI Vector",
   "R0-2delta CI Vector",
@@ -63,8 +68,11 @@ char* CI_Vector_Labels[MAX_NUM_DISP] = {
 
 const int MAX_GEOM_STRING=20;
 
+}} // namespace psi::dboc
+
 int main(int argc, char *argv[])
 {
+  using namespace psi::dboc;
   int i,j;
   int natom, num, junk;
   double **geom, *zvals;
@@ -88,6 +96,7 @@ int main(int argc, char *argv[])
   exit(0);
 }
 
+namespace psi { namespace dboc {
 
 /*--- parsing ---*/
 void parsing()
@@ -116,7 +125,7 @@ void parsing()
     Params.reftype = Params_t::uhf;
   else
     done("This HF reference is not supported at the moment");
-  delete[] reftype;
+  free(reftype);
 
   Params.delta = 0.0005;
   errcod = ip_data(":DBOC:DISPLACEMENT","%lf",&Params.delta,0);
@@ -197,15 +206,15 @@ void parsing()
     }
   }
 
-  int isotopes_given = ip_exist(":DBOC:ISOTOPES",0);
+  int isotopes_given = ip_exist("ISOTOPES",0);
   if (isotopes_given) {
     Params.nisotope = 0;
-    ip_count(":DBOC:ISOTOPES",&Params.nisotope,0);
+    ip_count("ISOTOPES",&Params.nisotope,0);
     if (Params.nisotope == 0)
       done("Keyword ISOTOPES should be a vector of num_atoms elements");
     Params.isotopes = new char*[Params.nisotope];
     for(int atom=0; atom<Params.nisotope; atom++) {
-      ip_string(":DBOC:ISOTOPES",&(Params.isotopes[atom]),1,atom);
+      ip_string("ISOTOPES",&(Params.isotopes[atom]),1,atom);
     }
   }
   else {
@@ -289,7 +298,7 @@ double* get_atomic_masses()
 
 // Remove PSI3 prefixed file
 void
-remove_psi3_file(char* name)
+remove_psi3_file(const char* name)
 {
   char* execstr = (char*) malloc( sizeof(char) * (strlen("/bin/rm -f ") +
                                                   strlen(psi_file_prefix) +
@@ -550,12 +559,12 @@ void init_io(int argc, char *argv[])
   progid = (char *) malloc(strlen(gprgid())+2);
   sprintf(progid, ":%s",gprgid());
 
-  int errcod = psi_start(argc-1,argv+1,0);
+  int errcod = psi_start(&infile,&outfile,&psi_file_prefix,argc-1,argv+1,0);
   if (errcod != PSI_RETURN_SUCCESS)
     throw std::runtime_error("init_io -- psi_start failed");
   ip_cwk_add(progid);
   tstart(outfile);
-  psio_init();
+  psio_init(); psio_ipv1_config();
 
   // Psi modules called by dboc should read from the same input file
   // set the value of PSI_INPUT for the duration of this run
@@ -573,7 +582,7 @@ void init_io(int argc, char *argv[])
   // Psi modules called by dboc should write to a different output file
   // reset the value of PSI_OUTPUT for the duration of this run
   orig_psi_output_env = getenv("PSI_OUTPUT");
-  char* ofname = (char*) malloc(strlen(psi_ofname())+1+strlen("dboc.findif.out"));
+  char* ofname = (char*) malloc(strlen(psi_ofname())+2+strlen("dboc.findif.out"));
   sprintf(ofname, "%s.dboc.findif.out", psi_ofname());
 #if HAVE_PUTENV
   char* tmpstr2 = (char *) malloc(12+strlen(ofname));
@@ -592,7 +601,7 @@ void exit_io()
 {
   psio_done();
   tstop(outfile);
-  psi_stop();
+  psi_stop(infile,outfile,psi_file_prefix);
 }
 
 void done(const char *message)
@@ -600,15 +609,17 @@ void done(const char *message)
   char* errmsg;
   errmsg = (char *) new char[strlen(message)+7];
   sprintf(errmsg,"DBOC: %s",message);
+  fprintf(outfile,"ERROR %s",errmsg);
   exit_io();
   throw std::runtime_error(errmsg);
   delete[] errmsg;
 }
 
+}} // namespace psi::dboc
 
-extern "C" char *gprgid()
+extern "C" const char *gprgid()
 {
-   char *prgid = "DBOC";
+   const char *prgid = "DBOC";
 
-   return(prgid);
+   return(const_cast<char*>(prgid));
 }
