@@ -1,7 +1,13 @@
+/*! \file
+    \ingroup DBOC
+    \brief Enter brief description of file here 
+*/
 
 #ifndef _psi3_dboc_dets_h_
 #define _psi3_dboc_dets_h_
 
+namespace psi{ namespace dboc {
+
 /// Det is a determinant to be sorted according to "indices" Ia and Ib (can be string indices, block indices, etc.)
 struct Det {
   int Ia;
@@ -21,4 +27,6 @@ inline bool detcomp(DetI i, DetI j)
   return false;
 }
 
+}} /* namespace psi::dboc */
+
 #endif
