@@ -1,11 +1,13 @@
-#include <stdio.h>
-#include <stdlib.h>
-extern "C" {
+/*! \file
+    \ingroup DBOC
+    \brief Enter brief description of file here 
+*/
+#include <cstdio>
+#include <cstdlib>
 #include <libciomr/libciomr.h>
 #include <libchkpt/chkpt.h>
 #include <libpsio/psio.h>
 #include <psifiles.h>
-}
 #include "defines.h"
 #include "float.h"
 #include "params.h"
@@ -17,16 +19,17 @@ extern "C" {
 #include <libbasis/overlap.h>
 #include <libbasis/rotation.h>
 
+namespace psi { namespace dboc {
+
 extern void done(const char * message);
-extern MOInfo_t MOInfo;
-extern FILE *outfile;
+extern "C" FILE *outfile;
 extern BasisSet* BasisSets[MAX_NUM_DISP];
 extern HFWavefunction* HFVectors[MAX_NUM_DISP];
 extern Params_t Params;
 
 FLOAT **eval_S_alpha(DisplacementIndex LDisp, DisplacementIndex RDisp)
 {
-
+  
   HFWavefunction* HFWfn_R = HFVectors[RDisp];
   HFWavefunction* HFWfn_L = HFVectors[LDisp];
   int num_ao = HFWfn_R->num_ao();
@@ -38,6 +41,7 @@ FLOAT **eval_S_alpha(DisplacementIndex LDisp, DisplacementIndex RDisp)
   double** rref_r = HFWfn_R->rref();
 
 #if USE_MOINFO
+  extern MOInfo_t MOInfo;
   int num_mo = MOInfo.num_mo;
   int num_so = MOInfo.num_so;
 #else
@@ -63,10 +67,10 @@ FLOAT **eval_S_alpha(DisplacementIndex LDisp, DisplacementIndex RDisp)
 
   if (Params.print_lvl > PrintLevels::print_contrib) {
     fprintf(outfile, "  -Rotation matrix for AO basis (disp = %d)\n", RDisp);
-    print_mat(basisRref_r, num_ao, num_ao, outfile);
+    psi::dboc::print_mat(basisRref_r, num_ao, num_ao, outfile);
     
     fprintf(outfile, "  -Rotation matrix for AO basis (disp = %d)\n", LDisp);
-    print_mat(basisRref_l, num_ao, num_ao, outfile);
+    psi::dboc::print_mat(basisRref_l, num_ao, num_ao, outfile);
 
     double** tmp_l1 = block_matrix(num_ao, num_mo);
     double** tmp_l2 = block_matrix(num_ao, num_mo);
@@ -78,14 +82,14 @@ FLOAT **eval_S_alpha(DisplacementIndex LDisp, DisplacementIndex RDisp)
     mmult(basisRref_l,0,tmp_l1,0,tmp_l2,0,num_ao,num_ao,num_mo,0);
     
     fprintf(outfile, "  -Original alpha eigenvector (disp = %d)\n", RDisp);
-    print_mat(tmp_r1, num_ao, num_mo, outfile);
+    psi::dboc::print_mat(tmp_r1, num_ao, num_mo, outfile);
     fprintf(outfile, "  -Rotated alpha eigenvector (disp = %d)\n", RDisp);
-    print_mat(tmp_r2, num_ao, num_mo, outfile);
+    psi::dboc::print_mat(tmp_r2, num_ao, num_mo, outfile);
     
     fprintf(outfile, "  -Original alpha eigenvector (disp = %d)\n", LDisp);
-    print_mat(tmp_l1, num_ao, num_mo, outfile);
+    psi::dboc::print_mat(tmp_l1, num_ao, num_mo, outfile);
     fprintf(outfile, "  -Rotated alpha eigenvector (disp = %d)\n", LDisp);
-    print_mat(tmp_l2, num_ao, num_mo, outfile);
+    psi::dboc::print_mat(tmp_l2, num_ao, num_mo, outfile);
   }
 
   double** tmpmat = block_matrix(num_ao,num_ao);
@@ -106,7 +110,7 @@ FLOAT **eval_S_alpha(DisplacementIndex LDisp, DisplacementIndex RDisp)
 
   if (Params.print_lvl > PrintLevels::print_contrib) {
     fprintf(outfile, " (%d/%d) overlap matrix (SO basis)\n", LDisp, RDisp);
-    print_mat(Slr_FLOAT, num_so, num_so, outfile);
+    psi::dboc::print_mat(Slr_FLOAT, num_so, num_so, outfile);
   }
 
   FLOAT** tmpmat1 = create_matrix(num_mo,num_so);
@@ -118,7 +122,7 @@ FLOAT **eval_S_alpha(DisplacementIndex LDisp, DisplacementIndex RDisp)
 
   if (Params.print_lvl > PrintLevels::print_contrib) {
     fprintf(outfile, "  (%d/%d) alpha overlap matrix (MO basis)\n", LDisp, RDisp);
-    print_mat(S, num_mo, num_mo, outfile);
+    psi::dboc::print_mat(S, num_mo, num_mo, outfile);
   }
 
   delete_matrix(tmpmat1);
@@ -143,6 +147,7 @@ FLOAT **eval_S_beta(DisplacementIndex LDisp, DisplacementIndex RDisp)
   double** rref_r = HFWfn_R->rref();
 
 #if USE_MOINFO
+  extern MOInfo_t MOInfo;
   int num_mo = MOInfo.num_mo;
   int num_so = MOInfo.num_so;
 #else
@@ -168,10 +173,10 @@ FLOAT **eval_S_beta(DisplacementIndex LDisp, DisplacementIndex RDisp)
 
   if (Params.print_lvl > PrintLevels::print_contrib) {
     fprintf(outfile, "  -Rotation matrix for AO basis (disp = %d)\n", RDisp);
-    print_mat(basisRref_r, num_ao, num_ao, outfile);
+    psi::dboc::print_mat(basisRref_r, num_ao, num_ao, outfile);
     
     fprintf(outfile, "  -Rotation matrix for AO basis (disp = %d)\n", LDisp);
-    print_mat(basisRref_l, num_ao, num_ao, outfile);
+    psi::dboc::print_mat(basisRref_l, num_ao, num_ao, outfile);
 
     double** tmp_l1 = block_matrix(num_ao, num_mo);
     double** tmp_l2 = block_matrix(num_ao, num_mo);
@@ -183,14 +188,14 @@ FLOAT **eval_S_beta(DisplacementIndex LDisp, DisplacementIndex RDisp)
     mmult(basisRref_l,0,tmp_l1,0,tmp_l2,0,num_ao,num_ao,num_mo,0);
     
     fprintf(outfile, "  -Original beta eigenvector (disp = %d)\n", RDisp);
-    print_mat(tmp_r1, num_ao, num_mo, outfile);
+    psi::dboc::print_mat(tmp_r1, num_ao, num_mo, outfile);
     fprintf(outfile, "  -Rotated beta eigenvector (disp = %d)\n", RDisp);
-    print_mat(tmp_r2, num_ao, num_mo, outfile);
+    psi::dboc::print_mat(tmp_r2, num_ao, num_mo, outfile);
     
     fprintf(outfile, "  -Original beta eigenvector (disp = %d)\n", LDisp);
-    print_mat(tmp_l1, num_ao, num_mo, outfile);
+    psi::dboc::print_mat(tmp_l1, num_ao, num_mo, outfile);
     fprintf(outfile, "  -Rotated beta eigenvector (disp = %d)\n", LDisp);
-    print_mat(tmp_l2, num_ao, num_mo, outfile);
+    psi::dboc::print_mat(tmp_l2, num_ao, num_mo, outfile);
   }
 
   double** tmpmat = block_matrix(num_ao,num_ao);
@@ -211,7 +216,7 @@ FLOAT **eval_S_beta(DisplacementIndex LDisp, DisplacementIndex RDisp)
 
   if (Params.print_lvl > PrintLevels::print_contrib) {
     fprintf(outfile, " (%d/%d) overlap matrix (SO basis)\n", LDisp, RDisp);
-    print_mat(Slr_FLOAT, num_so, num_so, outfile);
+    psi::dboc::print_mat(Slr_FLOAT, num_so, num_so, outfile);
   }
 
   FLOAT** tmpmat1 = create_matrix(num_mo,num_so);
@@ -223,7 +228,7 @@ FLOAT **eval_S_beta(DisplacementIndex LDisp, DisplacementIndex RDisp)
 
   if (Params.print_lvl > PrintLevels::print_contrib) {
     fprintf(outfile, "  (%d/%d) beta overlap matrix (MO basis)\n", LDisp, RDisp);
-    print_mat(S, num_mo, num_mo, outfile);
+    psi::dboc::print_mat(S, num_mo, num_mo, outfile);
   }
 
   delete_matrix(tmpmat1);
@@ -234,3 +239,4 @@ FLOAT **eval_S_beta(DisplacementIndex LDisp, DisplacementIndex RDisp)
   return S;
 }
 
+}} // namespace psi::dboc
