@@ -1,7 +1,13 @@
+/*! \file
+    \ingroup DBOC
+    \brief Enter brief description of file here 
+*/
 
 #ifndef _psi3_bin_dboc_moinfo_h_
 #define _psi3_bin_dboc_moinfo_h_
 
+namespace psi { namespace dboc {
+
 typedef struct {
   int num_so;
   int num_mo;
@@ -15,5 +21,7 @@ typedef struct {
   short int* QTS_to_pitzer;
 } MOInfo_t;
 
+}} /* namespace psi::dboc */
+
 #endif
 
