@@ -1,7 +1,13 @@
+/*! \file
+    \ingroup DBOC
+    \brief Enter brief description of file here 
+*/
 
 #ifndef _psi3_bin_dboc_params_h_
 #define _psi3_bin_dboc_params_h_
 
+namespace psi { namespace dboc {
+
 namespace PrintLevels {
   static const int print_intro = 1;
   static const int print_params = 1;
@@ -39,4 +45,6 @@ typedef struct {
 
 } Params_t;
 
+}} /* namespace psi::dboc */
+
 #endif
