@@ -1,20 +1,24 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-extern "C" {
+/*! \file
+    \ingroup DBOC
+    \brief Enter brief description of file here 
+*/
+#include <cstdio>
+#include <cstdlib>
+#include <cmath>
 #include <libciomr/libciomr.h>
 #include <libchkpt/chkpt.h>
 #include <libqt/qt.h>
 #include <psifiles.h>
-}
 #include "moinfo.h"
 #include "mo_overlap.h"
 #include "float.h"
 #include "linalg.h"
 #include "hfwfn.h"
 
+namespace psi { namespace dboc {
+
 extern MOInfo_t MOInfo;
-extern FILE *outfile;
+extern "C" FILE *outfile;
 extern HFWavefunction* HFVectors[MAX_NUM_DISP];
 
 extern void done(const char *);
@@ -115,3 +119,4 @@ double eval_uhf_derwfn_overlap(DisplacementIndex LDisp, DisplacementIndex RDisp)
   return (double)deter_a*deter_b;
 }
 
+}} // namespace psi::dboc
