@@ -1,103 +1,90 @@
-/*
-** DETCI
-**
-** DETERMINANT CI Program, incorporating Abelian point-group symmetry
-**
-** C. David Sherrill
-** Center for Computational Quantum Chemistry 
-** University of Georgia
-** August 1994
-**
-** Updated 3/95 to do frozen core and virtuals correctly
-** Updated 5/95 to do RAS CI's again 
-** Updated 2/96 to clean up code and rename DETCI
-** 
+/*! \defgroup DETCI detci: The Determinant CI code */
+
+/*! \file
+    \ingroup DETCI
+    \brief Determinant-based CI program
+
+   DETCI
+  
+   DETERMINANT CI Program, incorporating Abelian point-group symmetry
+  
+   C. David Sherrill
+   Center for Computational Quantum Chemistry 
+   University of Georgia
+   August 1994
+  
+   Updated 3/95 to do frozen core and virtuals correctly
+   Updated 5/95 to do RAS CI's again 
+   Updated 2/96 to clean up code and rename DETCI
+   
 */
 
-/* DEFINES */
-#define MIN0(a,b) (((a)<(b)) ? (a) : (b))
-#define MAX0(a,b) (((a)>(b)) ? (a) : (b))
-
-#include <math.h>
-
-extern "C" {
-
-   /* C INCLUDE FILES */
-
-   #include <stdlib.h>
-   #include <stdio.h>
-   #include <libipv1/ip_lib.h>
-   /* seem to need string.h in RedHat 7.1 */
-   #include <string.h>
-   #include <psifiles.h>
-   #include <libqt/qt.h>
-   #include <libciomr/libciomr.h>
-   #include <libchkpt/chkpt.h>
-   #include <libpsio/psio.h>
-   #include <libqt/slaterdset.h>
-   #include <masses.h>
-   #include "structs.h"
-   #include "globals.h"
-   #include "ci_tol.h"
-   #include <pthread.h>
-   #include "tpool.h"
-
-
-   /* C "GLOBAL" VARIABLES FOR THIS MODULE */
-
-   unsigned char ***Occs;
-   struct stringwr **alplist;  
-   struct stringwr **betlist; 
-
-
-   /* C FUNCTION PROTOTYPES */
-
-   extern void eivout_t(double **evecs, double *evals, int rows, int cols,
-      FILE *outfile);
-   extern void read_integrals(void);
-   extern void tf_onel_ints(int printflg, FILE *outfile);
-   extern void form_gmat(int printflg, FILE *outfile);
-   extern void get_mo_info(void);
-   extern void print_vec(unsigned int nprint, int *Iacode, int *Ibcode, 
-      int *Iaidx, int *Ibidx, double *coeff,
-      struct olsen_graph *AlphaG, struct olsen_graph *BetaG, 
-      struct stringwr **alplist, struct stringwr **betlist,
-      FILE *outfile);
-   extern void print_config(int nbf, int num_alp_el, int num_bet_el,
-      struct stringwr *stralp, struct stringwr *strbet, 
-      int num_fzc_orbs, char *outstring);
-   extern void init_stringwr_temps(int nel, int num_ci_orbs, int nsym);
-   extern void free_stringwr_temps(int nsym);
-   extern void str_abs2rel(int absidx, int *relidx, int *listnum,
-      struct olsen_graph *Graph);
-   extern int str_rel2abs(int relidx, int listnum, struct olsen_graph *Graph);
-   extern void H0block_init(unsigned int size);
-   extern void H0block_fill(struct stringwr **alplist, 
-      struct stringwr **betlist);
-   extern void H0block_free(void);
-   extern void H0block_print(void);
-   extern void H0block_setup(int num_blocks, int *Ia_code, int *Ib_code);
-   extern void H0block_pairup(int guess);
-   extern void H0block_spin_cpl_chk(void);
-   extern void H0block_filter_setup(void);
-   extern void sem_test(double **A, int N, int M, int L, double **evecs,
-      double *evals, double **b, double conv_e, double conv_rms, 
-      int maxiter, double offst, int *vu, int maxnvect, FILE *outfile);
-   extern void form_ov(struct stringwr **alplist);
-   extern void write_energy(int nroots, double *evals, double offset);
-}
-
-
-/* C++ INCLUDE FILES */
-
+#include <cstdio>
+#include <cstdlib>
+#include <cmath>
+#include <libipv1/ip_lib.h>
+#include <cstring>
+#include <psifiles.h>
+#include <libqt/qt.h>
+#include <libciomr/libciomr.h>
+#include <libchkpt/chkpt.h>
+#include <libpsio/psio.h>
+#include <libqt/slaterdset.h>
+#include <masses.h>
+#include "structs.h"
+#include "globals.h"
+#include "ci_tol.h"
+#include <pthread.h>
+#include "tpool.h"
 #include <iostream>
 #include "odometer.h"
 #include "slaterd.h"
 #include "civect.h"
 
+namespace psi { namespace detci {
 
+#define MIN0(a,b) (((a)<(b)) ? (a) : (b))
+#define MAX0(a,b) (((a)>(b)) ? (a) : (b))
 
-/* C++ FUNCTION PROTOTYPES */
+unsigned char ***Occs;
+struct stringwr **alplist;  
+struct stringwr **betlist; 
+
+extern void eivout_t(double **evecs, double *evals, int rows, int cols,
+   FILE *outfile);
+extern void read_integrals(void);
+extern void tf_onel_ints(int printflg, FILE *outfile);
+extern void zapt_shift(double *TEI, int nirreps, int nmo, int *doccpi, 
+   int *soccpi, int *orbspi, int *frzdoccpi, int *reorder);
+extern void form_gmat(int printflg, FILE *outfile);
+extern void get_mo_info(void);
+extern void print_vec(unsigned int nprint, int *Iacode, int *Ibcode, 
+   int *Iaidx, int *Ibidx, double *coeff,
+   struct olsen_graph *AlphaG, struct olsen_graph *BetaG, 
+   struct stringwr **alplist, struct stringwr **betlist,
+   FILE *outfile);
+extern void print_config(int nbf, int num_alp_el, int num_bet_el,
+   struct stringwr *stralp, struct stringwr *strbet, 
+   int num_fzc_orbs, char *outstring);
+extern void init_stringwr_temps(int nel, int num_ci_orbs, int nsym);
+extern void free_stringwr_temps(int nsym);
+extern void str_abs2rel(int absidx, int *relidx, int *listnum,
+   struct olsen_graph *Graph);
+extern int str_rel2abs(int relidx, int listnum, struct olsen_graph *Graph);
+extern void H0block_init(unsigned int size);
+extern void H0block_fill(struct stringwr **alplist, 
+   struct stringwr **betlist);
+extern void H0block_free(void);
+extern void H0block_print(void);
+extern void H0block_setup(int num_blocks, int *Ia_code, int *Ib_code);
+extern void H0block_pairup(int guess);
+extern void H0block_spin_cpl_chk(void);
+extern void H0block_filter_setup(void);
+extern void sem_test(double **A, int N, int M, int L, double **evecs,
+   double *evals, double **b, double conv_e, double conv_rms, 
+   int maxiter, double offst, int *vu, int maxnvect, FILE *outfile);
+extern void form_ov(struct stringwr **alplist);
+extern void write_energy(int nroots, double *evals, double offset);
 
 void init_io(int argc, char *argv[]);
 void close_io(void);
@@ -108,34 +95,39 @@ void diag_h(struct stringwr **strlista, struct stringwr **strlistb);
 void mpn(struct stringwr **strlista, struct stringwr **strlistb);
 void form_opdm(void);
 void form_tpdm(void);
-extern void diag_h_genci(struct stringwr **alplist, struct stringwr **betlist);
 extern void get_parameters(void);
 extern void print_parameters(void);
 extern void set_ras_parms(void);
+extern void print_ras_parms(void);
 extern void form_strings(void);
 extern void mitrush_iter(CIvect &Hd, 
-      struct stringwr **alplist, struct stringwr **betlist,
-      int nroots, double *evals, double conv_rms, double conv_e, double enuc, 
-      double efzc, int maxiter, int maxnvect, FILE *outfile, 
-      int print_lvl);
+   struct stringwr **alplist, struct stringwr **betlist,
+   int nroots, double *evals, double conv_rms, double conv_e, double enuc, 
+   double efzc, int maxiter, int maxnvect, FILE *outfile, 
+   int print_lvl);
 extern void sem_iter(CIvect &Hd, struct stringwr **alplist, struct stringwr
-      **betlist, double *evals, double conv_e,
-      double conv_rms, double enuc, double efzc,
-      int nroots, int maxiter, int maxnvect, FILE *outfile, int print_lvl);
+   **betlist, double *evals, double conv_e,
+   double conv_rms, double enuc, double efzc,
+   int nroots, int maxiter, int maxnvect, FILE *outfile, int print_lvl);
 extern void mpn_generator(CIvect &Hd, struct stringwr **alplist, 
-          struct stringwr **betlist);
+   struct stringwr **betlist);
 extern void opdm(struct stringwr **alplist, struct stringwr **betlist, 
-          int transdens, int dipmom,
-          int Inroots, int Iroot, int Inunits, int Ifirstunit,
-          int Jnroots, int Jroot, int Jnunits, int Jfirstunit,
-          int targetfile, int writeflag, int printflag);
+   int transdens, int dipmom,
+   int Inroots, int Iroot, int Inunits, int Ifirstunit,
+   int Jnroots, int Jroot, int Jnunits, int Jfirstunit,
+   int targetfile, int writeflag, int printflag);
 extern void tpdm(struct stringwr **alplist, struct stringwr **betlist, 
-          int Inroots, int Inunits, int Ifirstunit,
-          int Jnroots, int Jnunits, int Jfirstunit,
-          int targetfile, int writeflag, int printflag);
+   int Inroots, int Inunits, int Ifirstunit,
+   int Jnroots, int Jnunits, int Jfirstunit,
+   int targetfile, int writeflag, int printflag);
+extern void compute_cc(void);
 extern void calc_mrpt(void);
 
-main(int argc, char *argv[])
+}} // namespace psi::detci
+
+using namespace psi::detci;
+
+int main(int argc, char *argv[])
 {
    Parameters.print_lvl = 1;
    Parameters.have_special_conv = 0;
@@ -147,12 +139,14 @@ main(int argc, char *argv[])
    init_ioff();                 /* set up the ioff array                    */
    title();                     /* print program identification             */
    get_mo_info();               /* read DOCC, SOCC, frozen, nmo, etc        */
-   
-   if (Parameters.print_lvl)
-     print_parameters();       /* print running parameters                 */
-
    set_ras_parms();             /* set fermi levels and the like            */ 
+   
+   if (Parameters.print_lvl) {
+     print_parameters();       /* print running parameters                 */
+     print_ras_parms();
+   }
    fflush(outfile); 
+
    form_strings();              /* form the alpha/beta strings              */
    if (Parameters.pthreads)
      tpool_init(&thread_pool, Parameters.nthreads, CalcInfo.num_alp_str, 0);
@@ -168,29 +162,26 @@ main(int argc, char *argv[])
    
    read_integrals();            /* get the 1 and 2 elec MO integrals        */
 
-   if (Parameters.genci) 
-     diag_h_genci(alplist, betlist);
+   if(Parameters.zaptn)         /* Shift SCF eigenvalues for ZAPTn          */
+      zapt_shift(CalcInfo.twoel_ints, CalcInfo.nirreps, CalcInfo.nmo,
+         CalcInfo.docc, CalcInfo.socc, CalcInfo.orbs_per_irr,
+         CalcInfo.frozen_docc, CalcInfo.reorder);
 
-   /*
-   else if (Parameters.mrpt)
-     calc_mrpt();
-   */
-
-   else {
-     if (Parameters.bendazzoli) /* form the Bendazzoli OV arrays            */
-        form_ov(alplist);
+   if (Parameters.bendazzoli) /* form the Bendazzoli OV arrays            */
+      form_ov(alplist);
                                 /* lump together one-electron contributions */
-     tf_onel_ints((Parameters.print_lvl>3), outfile);   
+   tf_onel_ints((Parameters.print_lvl>3), outfile);   
 
                                 /* form the RAS g matrix (eq 28-29)         */
-     form_gmat((Parameters.print_lvl>3), outfile); 
-     fflush(outfile);
+   form_gmat((Parameters.print_lvl>3), outfile); 
+   fflush(outfile);
 
    if (Parameters.mpn)
      mpn(alplist, betlist);
+   else if (Parameters.cc)
+     compute_cc();
    else
      diag_h(alplist, betlist);
-   }
 
    if (Parameters.opdm || Parameters.transdens) form_opdm();
    if (Parameters.tpdm) form_tpdm();
@@ -201,7 +192,7 @@ main(int argc, char *argv[])
    return(0);
 }
 
-
+namespace psi { namespace detci {
 
 /*
 ** init_io(): Figure out command-line arguments and start up I/O for
@@ -244,7 +235,7 @@ void init_io(int argc, char *argv[])
     * we do pointer arithmetic on argv
     */
    /* init_in_out(argc-parsed,argv+parsed); */
-   errcod = psi_start(num_unparsed,argv_unparsed,0);
+   errcod = psi_start(&infile,&outfile,&psi_file_prefix,num_unparsed,argv_unparsed,0);
 
    if (Parameters.print_lvl) tstart(outfile);
 
@@ -256,7 +247,7 @@ void init_io(int argc, char *argv[])
    ip_cwk_add(":DEFAULT");
    */
    ip_cwk_add(":DETCI");
-   psio_init();
+   psio_init(); psio_ipv1_config();
    
 }
  
@@ -288,7 +279,7 @@ void close_io(void)
    int errcod;
    psio_done();
    if (Parameters.print_lvl) tstop(outfile);
-   errcod = psi_stop();
+   errcod = psi_stop(infile,outfile,psi_file_prefix);
 }
 
 
@@ -467,7 +458,8 @@ void diag_h(struct stringwr **alplist, struct stringwr **betlist)
 
          for (i=0; i<nroots; i++) {
             fprintf(outfile, 
-               "\n\nROOT%2d ECI = %17.13lf\n",i+1,evals[i]+nucrep);
+               "\n\n* ROOT %2d CI total energy = %17.13lf\n",
+               i+1,evals[i]+nucrep);
             Cvec.setarray(evecs[i], size);
             zero_arr(mi_coeff, Parameters.nprint);
             Cvec.max_abs_vals(Parameters.nprint, mi_iac, mi_ibc, mi_iaidx,
@@ -766,7 +758,8 @@ void diag_h(struct stringwr **alplist, struct stringwr **betlist)
 
          for (i=0; i<nroots; i++) {
             fprintf(outfile, 
-               "\n\nROOT%2d ECI = %17.13lf\n",i+1,evals[i]+nucrep);
+               "\n\n* ROOT %2d CI total energy = %17.13lf\n",
+               i+1,evals[i]+nucrep);
             Cvec.setarray(evecs[i], size);
             zero_arr(mi_coeff, Parameters.nprint);
             Cvec.max_abs_vals(Parameters.nprint, mi_iac, mi_ibc, mi_iaidx,
@@ -1319,15 +1312,27 @@ void mpn(struct stringwr **alplist, struct stringwr **betlist)
      CalcInfo.e0_fzc += tval; 
      }
 
-  for (i=0; i<CalcInfo.num_alp_expl; i++) {
-     j = (stralp->occs)[i] + CalcInfo.num_fzc_orbs;
-     CalcInfo.e0 += CalcInfo.scfeigval[j];
-     }
+  if(Parameters.zaptn) { 
+    for (i=0; i<CalcInfo.num_alp_expl; i++) {
+       j = (stralp->occs)[i] + CalcInfo.num_fzc_orbs;
+       CalcInfo.e0 += CalcInfo.scfeigvala[j];
+       }
 
-  for (i=0; i<CalcInfo.num_bet_expl; i++) {
-     j = (strbet->occs)[i] + CalcInfo.num_fzc_orbs;
-     CalcInfo.e0 += CalcInfo.scfeigval[j];
-     }
+    for (i=0; i<CalcInfo.num_bet_expl; i++) {
+       j = (strbet->occs)[i] + CalcInfo.num_fzc_orbs;
+       CalcInfo.e0 += CalcInfo.scfeigvalb[j];
+       }
+    } else {
+    for (i=0; i<CalcInfo.num_alp_expl; i++) {
+       j = (stralp->occs)[i] + CalcInfo.num_fzc_orbs;
+       CalcInfo.e0 += CalcInfo.scfeigval[j];
+       }
+
+    for (i=0; i<CalcInfo.num_bet_expl; i++) {
+       j = (strbet->occs)[i] + CalcInfo.num_fzc_orbs;
+       CalcInfo.e0 += CalcInfo.scfeigval[j];
+       }
+    }
  
    /* prepare the H0 block */
           
@@ -1339,3 +1344,22 @@ void mpn(struct stringwr **alplist, struct stringwr **betlist)
 
    mpn_generator(Hd, alplist, betlist);
 }
+
+BIGINT strings2det(int alp_code, int alp_idx, int bet_code, int bet_idx) {
+
+   int blknum;
+   BIGINT addr;
+
+   blknum = CIblks.decode[alp_code][bet_code];
+   addr = CIblks.offset[blknum];
+   addr += alp_idx * CIblks.Ib_size[blknum] + bet_idx;
+
+   return(addr);
+
+}
+
+
+}} // namespace psi::detci
+
+extern "C" { const char *gprgid(void) { const char *prgid = "DETCI"; return (prgid); } }
+
