@@ -1,9 +1,9 @@
-/* 
-** GRAPHSET.CC
+/*! \file
+**  \ingroup DETCI
+**  \brief Routines needed to maintain the GraphSet Object.  
 **
-** Routines needed to maintain the GraphSet Object.  The graph
-** for alpha/beta strings has a different subgraph for each value of
-** irrep and RAS I hole/RAS III particle/RAS IV particle combination.  
+** The graph for alpha/beta strings has a different subgraph for each value 
+** of irrep and RAS I hole/RAS III particle/RAS IV particle combination.  
 **
 ** C. David Sherrill, May 1996
 ** Based on previous code by David Sherrill, 1994-5
@@ -12,31 +12,30 @@
 
 #define EXTERN
 
-extern "C" {
-   #include <stdlib.h>
-   #include <stdio.h>
-   #include <libciomr/libciomr.h>
-   #include <libqt/qt.h>
-   #include "structs.h"
-   #include "globals.h"
-   extern struct stringwr **alplist;  
-   extern struct stringwr **betlist; 
-
-   extern void gs_stringlist(struct graph_set *AG, struct stringwr **slist);
-   extern void gs_set_ciblks(struct graph_set *AG, struct graph_set *BG);
-   extern void print_ci_space(struct stringwr *strlist, int num_strings,
-      int nirreps, int strtypes, int nel, FILE *outfile);
-} ;
-
+#include <cstdlib>
+#include <cstdio>
+#include <libciomr/libciomr.h>
+#include <libqt/qt.h>
+#include "structs.h"
+#include "globals.h"
 #include <iostream>
-#define ODOMETER_DECL_ONLY
 #include "odometer.h"
 
+namespace psi { namespace detci {
+
+extern struct stringwr **alplist;  
+extern struct stringwr **betlist; 
+
+extern void gs_stringlist(struct graph_set *AG, struct stringwr **slist);
+extern void gs_set_ciblks(struct graph_set *AG, struct graph_set *BG);
+extern void print_ci_space(struct stringwr *strlist, int num_strings,
+   int nirreps, int strtypes, int nel, FILE *outfile);
+
 #define UOC_BIT 1
 #define OCC_BIT 2
 #define N_RAS_SPACES 4
 
-#define DEBUG 
+//#define DEBUG 
 
 /* GLOBALS THIS MODULE */
 int **Tij, **Toij;
@@ -302,7 +301,7 @@ void graphset(struct graph_set *GraphSet, int ci_orbs, int num_el,
       GraphSet->encode[1][i] = encode_tmp[1][i];
       GraphSet->encode[2][i] = encode_tmp[2][i];
       } 
-   free_int_matrix(encode_tmp, 3);
+   free_int_matrix(encode_tmp);
  
  
    GraphSet->num_codes = code;
@@ -1178,4 +1177,5 @@ void gs_free_repinfo_temps(void)
    free(Tsgn);
 }
 
+}} // namespace psi::detci
 
