@@ -1,7 +1,6 @@
-/*
-** MITRUSH_ITER.CC
-**
-** Contains code to do a Mitrushenkov iterative scheme for RAS CI's
+/*! \file
+**  \ingroup DETCI
+**  \brief Mitrushenkov iterative scheme for RAS CI's
 **
 ** C. David Sherrill
 ** Center for Computational Quantum Chemistry
@@ -18,34 +17,33 @@
 #define EXTERN 
 /* #define DEBUG */
 
-#include <math.h>
-
-extern "C" {
-   #include <stdlib.h>
-   #include <stdio.h>
-   #include <libciomr/libciomr.h>
-   #include <libqt/qt.h>
-   #include "structs.h"
-   #include "globals.h"
-
-   extern int H0block_calc(double E);
-   extern int H0block_coupling_calc(double E, struct stringwr *alplist,
-      struct stringwr *betlist);
-   extern void H0block_xy(double *x, double *y, double E);
-   extern void print_vec(unsigned int nprint, int *Iacode, int *Ibcode, 
-      int *Iaidx, int *Ibidx, double *coeff,
-      struct olsen_graph *AlphaG, struct olsen_graph *BetaG, 
-      struct stringwr **alplist, struct stringwr **betlist,
-      FILE *outfile);
-}
-
+#include <cstdlib>
+#include <cstdio>
+#include <cmath>
+#include <libciomr/libciomr.h>
+#include <libqt/qt.h>
+#include "structs.h"
+#include "globals.h"
 #include "civect.h"
 #include "ci_tol.h"
 
-/* #define DEBUG */
+namespace psi { namespace detci {
 
+extern int H0block_calc(double E);
+extern int H0block_coupling_calc(double E, struct stringwr *alplist,
+   struct stringwr *betlist);
+extern void H0block_xy(double *x, double *y, double E);
+extern void print_vec(unsigned int nprint, int *Iacode, int *Ibcode, 
+   int *Iaidx, int *Ibidx, double *coeff,
+   struct olsen_graph *AlphaG, struct olsen_graph *BetaG, 
+   struct stringwr **alplist, struct stringwr **betlist,
+   FILE *outfile);
+
+
+/* #define DEBUG */
 #define MITRUSH_E_DIFF_MIN 5.0E-6
 
+
 /*
 ** mitrush_iter()
 **
@@ -487,7 +485,7 @@ void mitrush_iter(CIvect &Hd, struct stringwr **alplist, struct stringwr
         free_matrix(H2x2,2);
         free(evals2x2);
         free_matrix(evecs2x2,2);
-        fprintf(outfile, "\n\nROOT 1 ECI = %19.15lf\n", E + enuc);
+        fprintf(outfile, "\n\n* ROOT 1 CI total energy = %19.15lf\n", E + enuc);
 
         Cvec.max_abs_vals(Parameters.nprint, mi_iac, mi_ibc, mi_iaidx,
            mi_ibidx, mi_coeff, Parameters.neg_only);
@@ -510,3 +508,6 @@ void mitrush_iter(CIvect &Hd, struct stringwr **alplist, struct stringwr
       } /* end while (1) */
 
 }
+
+}} // namespace psi::detci
+
