@@ -1,3 +1,8 @@
+/*! \file
+    \ingroup DETCI
+    \brief Enter brief description of file here 
+*/
+
 /*
 ** Moeller Plesset Perturbation Series Generator
 **
@@ -8,27 +13,27 @@
 
 /* #define DEBUG */
 
-#include <math.h>
-
-extern "C" {
-   #include <stdlib.h>
-   #include <stdio.h>
-   #include <libciomr/libciomr.h>
-   #include <libqt/qt.h>
-   #include <libchkpt/chkpt.h>
-   #include "structs.h"
-   #include "ci_tol.h"
-   #define EXTERN
-   #include "globals.h"
-   extern void print_vec(unsigned int nprint, int *Iacode, int *Ibcode,
-      int *Iaidx, int *Ibidx, double *coeff,
-      struct olsen_graph *AlphaG, struct olsen_graph *BetaG,
-      struct stringwr **alplist, struct stringwr **betlist,
-      FILE *outfile);
-}
-
+#include <cstdlib>
+#include <cstdio>
+#include <cmath>
+#include <libciomr/libciomr.h>
+#include <libqt/qt.h>
+#include <libchkpt/chkpt.h>
+#include "structs.h"
+#include "ci_tol.h"
+#define EXTERN
+#include "globals.h"
 #include "civect.h"
 
+namespace psi { namespace detci {
+
+extern void print_vec(unsigned int nprint, int *Iacode, int *Ibcode,
+   int *Iaidx, int *Ibidx, double *coeff,
+   struct olsen_graph *AlphaG, struct olsen_graph *BetaG,
+   struct stringwr **alplist, struct stringwr **betlist,
+   FILE *outfile);
+
+
 void mpn_generator(CIvect &Hd, struct stringwr **alplist, 
       struct stringwr **betlist)
 {
@@ -97,11 +102,16 @@ void mpn_generator(CIvect &Hd, struct stringwr **alplist,
   fprintf(outfile,"   CalcInfo.e0   = %25.15f\n", CalcInfo.e0);
   fprintf(outfile,"   CalcInfo.enuc = %25.15f\n", CalcInfo.enuc);
   fprintf(outfile,"   CalcInfo.e1   = %25.15f\n\n", CalcInfo.e1);
-  fprintf(outfile,"   n         Corr. Energy \t\t E(MPn) \t\t"
-      "   n         Corr. Energy \t\t E(MPn)\n\n");
+  if(Parameters.zaptn) {
+    fprintf(outfile,"   n         Corr. Energy \t\t E(ZAPTn) \t\t"
+        "   n         Corr. Energy \t\t E(ZAPTn)\n\n");
+    } else {
+    fprintf(outfile,"   n         Corr. Energy \t\t E(MPn) \t\t"
+        "   n         Corr. Energy \t\t E(MPn)\n\n");
+    }
   fprintf(outfile,"   0  %25.15f %25.15f\n", 0.0000000000,
       CalcInfo.e0+CalcInfo.enuc);
-  fprintf(outfile,"   1  %25.15f %25.15f\n",mpk_energy[1]+CalcInfo.enuc, 
+  fprintf(outfile,"   1  %25.15f %25.15f\n",mpk_energy[1],
       mpk_energy[0]+mpk_energy[1]+CalcInfo.enuc);
   Empn = mpk_energy[0]+mpk_energy[1]+CalcInfo.enuc;
   Empn2 = Empn;
@@ -149,7 +159,7 @@ void mpn_generator(CIvect &Hd, struct stringwr **alplist,
  
   tval += CalcInfo.efzc - mpk_energy[0]; 
  
-  fprintf(outfile,"   1  %25.15f %25.15f\n", tval+CalcInfo.enuc, 
+  fprintf(outfile,"   1  %25.15f %25.15f\n", tval,
    tval+mpk_energy[0]+CalcInfo.enuc);
   if (tval - mpk_energy[1] > ZERO) 
     fprintf(outfile, "First-order energies do not agree!\n");
@@ -185,7 +195,7 @@ void mpn_generator(CIvect &Hd, struct stringwr **alplist,
     }
 
   /* Here buffer1 = Cvec and buffer2 = Sigma */
-  k=1;
+  k=1; 
   while (k<Parameters.maxnvect) {
 
      /* Form Sigma */
@@ -219,7 +229,6 @@ void mpn_generator(CIvect &Hd, struct stringwr **alplist,
  
      Sigma.buf_unlock();
      if (Parameters.wigner) {
-       if (Parameters.zero_blocks) Cvec2.copy_offset_filenumber(Cvec);
        Cvec.wigner_E2k_formula(Hd, Sigma, Cvec2, alplist, betlist, buffer1,
           buffer2, k, mp2k_energy, wfn_overlap, cvec_coeff, cvec_norm, kvec_offset);
        Empn2 += mp2k_energy[2*k];
@@ -283,10 +292,8 @@ void mpn_generator(CIvect &Hd, struct stringwr **alplist,
        }
 
      /* Construct k+1th order wavefunction */
-     if (Parameters.zero_blocks) Cvec2.copy_offset_filenumber(Cvec);
      Cvec.construct_kth_order_wf(Hd, Sigma, Cvec2, alplist, betlist, buffer1,
         buffer2, k+1, mpk_energy, cvec_coeff, cvec_norm);
-     if (Parameters.zero_blocks) Cvec2.copy_offset_filenumber(Cvec);
      
      // fprintf(outfile, "Cvec %d = \n", k+1);
      // Cvec.print(outfile);
@@ -311,18 +318,34 @@ void mpn_generator(CIvect &Hd, struct stringwr **alplist,
    chkpt_init(PSIO_OPEN_OLD);
    if (Parameters.save_mpn2 == 1 && Parameters.wigner) {
      chkpt_wt_etot(Empn2);
-     fprintf(outfile, "\nMP%d energy saved\n", (Parameters.maxnvect * 2) - 1);
+     if(Parameters.zaptn) 
+       fprintf(outfile, "\nZAPT%d energy saved\n", (Parameters.maxnvect * 2) - 1);
+     else
+       fprintf(outfile, "\nMP%d energy saved\n", (Parameters.maxnvect * 2) - 1);
    }
    else if (Parameters.save_mpn2 == 2 && Parameters.wigner) {
      chkpt_wt_etot(Empn2a);
-     fprintf(outfile, "\nMP%d energy saved\n", (Parameters.maxnvect * 2) - 2);
+     if(Parameters.zaptn)
+       fprintf(outfile, "\nZAPT%d energy saved\n", (Parameters.maxnvect * 2) - 2);
+     else
+       fprintf(outfile, "\nMP%d energy saved\n", (Parameters.maxnvect * 2) - 2);
    }
    else {
      chkpt_wt_etot(Empn);
-     fprintf(outfile, "\nMP%d energy saved\n", Parameters.maxnvect);
+     if(Parameters.zaptn)
+       fprintf(outfile, "\nZAPT%d energy saved\n", Parameters.maxnvect);
+     else
+       fprintf(outfile, "\nMP%d energy saved\n", Parameters.maxnvect);
    }
+   if(Parameters.zaptn)
+     fprintf(outfile, "\nEZAPTn = %17.13lf\n", chkpt_rd_etot());
+   else
+     fprintf(outfile, "\nEMPn = %17.13lf\n", chkpt_rd_etot());
+
    chkpt_close();
 
    fprintf(outfile,"\n");
 }
 
+}} // namespace psi::detci
+
