@@ -1,3 +1,8 @@
+/*! \file
+    \ingroup DETCI
+    \brief Enter brief description of file here 
+*/
+
 /* 
 ** OLSENGRAPH.CC
 **
@@ -11,50 +16,46 @@
 */
 
 #define EXTERN
-
-extern "C" {
-   #include <stdlib.h>
-   #include <stdio.h>
-   #include <libciomr/libciomr.h>
-   #include <libqt/qt.h>
-   #include "structs.h"
-   #include "globals.h"
-   extern struct stringwr **alplist;  
-   extern struct stringwr **betlist; 
-
-   extern void stringlist(struct olsen_graph *Graph, struct stringwr **slist);
-   extern void set_ciblks(struct olsen_graph *AG, struct olsen_graph *BG);
-   extern void print_ci_space(struct stringwr *strlist, int num_strings,
-      int nirreps, int strtypes, int nel, FILE *outfile);
-   extern void str_abs2rel(int absidx, int *relidx, int *listnum,
-      struct olsen_graph *Graph);
-} ;
-
+#include <cstdlib>
+#include <cstdio>
+#include <libciomr/libciomr.h>
+#include <libqt/qt.h>
+#include "structs.h"
+#include "globals.h"
 #include <iostream>
-#define ODOMETER_DECL_ONLY
 #include "odometer.h"
 
+namespace psi { namespace detci {
+
+extern struct stringwr **alplist;  
+extern struct stringwr **betlist; 
+
+extern void stringlist(struct olsen_graph *Graph, struct stringwr **slist);
+extern void set_ciblks(struct olsen_graph *AG, struct olsen_graph *BG);
+extern void print_ci_space(struct stringwr *strlist, int num_strings,
+   int nirreps, int strtypes, int nel, FILE *outfile);
+extern void str_abs2rel(int absidx, int *relidx, int *listnum,
+   struct olsen_graph *Graph);
 
 //#define DEBUG  
 
 /* FUNCTION PROTOTYPES for this module */
 void olsengraph(struct olsen_graph *Graph, int ci_orbs, int num_el, 
-      int nirreps, int *orbsym, int ras1_lvl, int ras1_min, int ras1_max, 
-      int ras3_lvl, int ras3_max, int num_fzc_orbs, int num_cor_orbs,
-      int ras4_lvl, int ras4_max, int ras34_max);
+   int nirreps, int *orbsym, int ras1_lvl, int ras1_min, int ras1_max, 
+   int ras3_lvl, int ras3_max, int num_fzc_orbs, int num_cor_orbs,
+   int ras4_lvl, int ras4_max, int ras34_max);
 void og_add_walk(int ras1_idx, int ras3_num, int ras4_num, int *occs, 
-      int nel_expl, int norb, int nirreps, int num_fzc_orbs,
-      struct olsen_graph *Graph);
+   int nel_expl, int norb, int nirreps, int num_fzc_orbs,
+   struct olsen_graph *Graph);
 int og_calc_y(struct level *lvl, int ci_orbs);
 void og_fill(int num_el, int norb, int nirreps, int num_fzc_orbs,
-      struct olsen_graph *Graph);
+   struct olsen_graph *Graph);
 int subgr_lex_addr(struct level *head, int *occs, int nel, int norb);
 int og_lex_addr(struct olsen_graph *Graph, int *occs, int nel,
-      int *listnum);
+   int *listnum);
 void og_print(struct olsen_graph *Graph, FILE *outfile);
 
 
-
 /*
 ** form_strings(): Form the alpha and beta string graphs.  Use a different
 **    graph for every irrep * (num el in RAS I) * (num el in RAS III)
@@ -324,7 +325,7 @@ void olsengraph(struct olsen_graph *Graph, int ci_orbs, int num_el,
       Graph->encode[1][i] = encode_tmp[1][i];
       Graph->encode[2][i] = encode_tmp[2][i];
       } 
-   free_int_matrix(encode_tmp, 3);
+   free_int_matrix(encode_tmp);
  
  
    Graph->subgr_per_irrep = code;
@@ -454,8 +455,8 @@ void olsengraph(struct olsen_graph *Graph, int ci_orbs, int num_el,
    for (i=0; i<nirreps; i++) {
       for (j=0; j<code; j++) {
          sgptr = Graph->sg[i] + j;
-         free_int_matrix(sgptr->ktmp[0], maxj);
-         free_int_matrix(sgptr->ktmp[1], maxj);
+         free_int_matrix(sgptr->ktmp[0]);
+         free_int_matrix(sgptr->ktmp[1]);
          }
       }
 
@@ -840,4 +841,6 @@ void og_print(struct olsen_graph *Graph, FILE *outfile)
    fflush(outfile);
 }
 
+}} // namespace psi::detci
+
 
