@@ -1,5 +1,7 @@
 /*###########################################################################*/
-/*! \file zmat.cc
+/*! 
+  \file
+  \ingroup EXTREMA
   \brief Member functions for z-matrix derived class
   
   Contains the zmat constructor, method driver functions, interfaces
@@ -11,7 +13,7 @@
 #define EXTERN
 #include"extrema.h"
 
-
+using namespace psi::extrema;
 
 /*---------------------------------------------------------------------------*/
 /*! \fn zmat::zmat() 
@@ -35,7 +37,7 @@ zmat :: zmat() : internals()
   num_entries = chkpt_rd_nallatom();
   z_geom = chkpt_rd_zmat();
   char **temp_felement;
-  felement = chkpt_rd_felement();
+  felement = (char **) chkpt_rd_felement();
 
   dummy=0;
   for(i=0;i<num_entries;++i) 
