@@ -1,8 +1,12 @@
 /*##########################################################################*/
-/*! \file extrema.h
+/*! \file
+    \ingroup EXTREMA
   \brief Included header files, function declarations, and variables. */
 /*##########################################################################*/
 
+#ifndef _psi_bin_extrema_extrema_h_
+#define _psi_bin_extrema_extrema_h_
+
 #ifdef EXTERN
 # undef EXTERN
 # define EXTERN extern
@@ -10,28 +14,34 @@
 # define EXTERN
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <math.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cmath>
 
-extern "C" {
-#include <ctype.h>
+#include <cctype>
 #include <psifiles.h>
 #include <libciomr/libciomr.h>
 #include <libipv1/ip_lib.h>
 #include <libchkpt/chkpt.h>
 #include <libpsio/psio.h>
 #include <physconst.h>
-} 
-
 #include "defines.h"
+#include "math_tools.h"
+#include "coord_base.h"
+#include "simple.h"
+#include "internals.h"
+#include "zmat.h"
+#include "deloc.h"
 
+namespace psi { namespace extrema {
 void punt(char*);
 double **symm_matrix_invert(double**, int, int, int);
 
+extern "C" {
 EXTERN FILE *infile, *outfile;
 EXTERN char *psi_file_prefix;
+}
 
 EXTERN int coord_type;
 EXTERN int errcod, error;
@@ -41,13 +51,6 @@ extern "C" {
     char *gprgid();
 }
 
-#include "math_tools.h"
-#include "coord_base.h"
-#include "simple.h"
-#include "internals.h"
-#include "zmat.h"
-#include "deloc.h"
-
 /*inline function declarations*/
 inline double *unit_vec(double* cart_arr, int atom1, int atom2 );
 inline double vec_norm(double* cart_arr, int atom1, int atom2 );
@@ -58,4 +61,7 @@ inline double compute_bond(double *car, int atm, int bnd);
 inline double compute_angle(double *car, int atm, int bnd, int ang);
 inline double compute_torsion(double *car, int atm, int bnd, int ang, int tor);
 
+}} // namespace psi::extrema
+
+#endif // header guard
 
