@@ -1,18 +1,29 @@
+/*! \defgroup GIAO giao: Gauge-Including Atomic Orbitals */
+
+/*! 
+** \file
+** \ingroup GIAO
+** \brief Gauge-Including Atomic Orbitals
+*/
+
 
 #include <stdexcept>
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-extern "C" {
+#include <cstdio>
+#include <cstdlib>
+#include <cmath>
+#include <cstring>
 #include <libciomr/libciomr.h>
 #include <libchkpt/chkpt.h>
 #include <libiwl/iwl.h>
 #include <psifiles.h>
+
+extern "C" {
+  FILE* infile;
+  FILE* outfile;
+  char* psi_file_prefix;
 }
 
-FILE* infile;
-FILE* outfile;
-char* psi_file_prefix;
+namespace psi { namespace giao {
 
 static const int IOFFMAX = 1024;
 static int ioff[IOFFMAX];
@@ -33,13 +44,17 @@ void print_1e(const char* label, double** ints, int nbf);
 void print_2e(const char* label, double* ints, int nbf, double cutoff);
 void print_2e_canon(const char* label, double* ints, int nbf, double cutoff);
 
+}} // namespace psi::giao
+
 int main(int argc, char* argv[])
 {
-  int errcod = psi_start(argc-1,argv+1,0);
+  using namespace psi::giao;
+  
+  int errcod = psi_start(&infile,&outfile,&psi_file_prefix,argc-1,argv+1,0);
   if (errcod != PSI_RETURN_SUCCESS)
     throw std::runtime_error("main -- psi_start failed");
   tstart(outfile);
-  psio_init();
+  psio_init(); psio_ipv1_config();
   chkpt_init(PSIO_OPEN_OLD);
   init_misc();
   
@@ -270,16 +285,17 @@ int main(int argc, char* argv[])
   chkpt_close();
   psio_done();
   tstop(outfile);
-  psi_stop();
+  psi_stop(infile,outfile,psi_file_prefix);
   exit(0);
 }
 
 extern "C" const char* gprgid()
 {
-  static char* prgid = ":GIAO";
+  const char* prgid = "GIAO";
   return prgid;
 }
 
+namespace psi { namespace giao {
 
 void init_misc()
 {
@@ -590,3 +606,5 @@ void print_2e_canon(const char* label, double* ints, int nbf, double cutoff)
 
   return;
 }
+
+}} // namespace psi:giao
