@@ -1,6 +1,10 @@
+/*! \file
+    \ingroup INPUT
+    \brief Enter brief description of file here 
+*/
 
-#ifndef _psi3_dboc_float_h_
-#define _psi3_dboc_float_h_
+#ifndef _psi3_bin_input_float_h_
+#define _psi3_bin_input_float_h_
 
 #include "defines.h"
 
@@ -20,4 +24,4 @@
 #  define SQRT sqrt
 #endif
 
-#endif
+#endif // header guard
