@@ -1,7 +1,14 @@
+/*! \file
+    \ingroup INPUT
+    \brief Enter brief description of file here 
+*/
 /***************************
     Global variables
  ***************************/
 
+#ifndef _psi3_bin_input_global_h_
+#define _psi3_bin_input_global_h_
+
 /*need this for z_entry structure*/
 #include <libchkpt/chkpt.h>
 
@@ -12,6 +19,8 @@
 # define EXTERN
 #endif
 
+namespace psi { namespace input {
+
 /*--- NOTE!
   Whenever I refer to basis function - it means either puream/cart function
   AO means cartesian Gaussian
@@ -25,11 +34,14 @@ struct coordinates{
 };
 
 /*Super-global stuff - the same no matter what calculation is running */
-EXTERN FILE *infile, *outfile;
-EXTERN char *psi_file_prefix;
+extern "C" {
+  EXTERN FILE *infile, *outfile;
+  EXTERN char *psi_file_prefix;
+}
 EXTERN int *ioff;
 EXTERN double *df;                  /*df[i] = (i-1)!!*/
 EXTERN char **elem_name;            /*Element names*/
+EXTERN char *wfn;
 
 /*Calculation options*/
 EXTERN int cartOn;                  /*Cartesian input flag*/
@@ -59,7 +71,7 @@ EXTERN char *frozen_core;           /*Frozen core option*/
 EXTERN char *frozen_virt;           /*Frozen virtuals option*/
 
 /*Labels*/
-EXTERN char *label;                 /*Label*/
+EXTERN const char *label;                 /*Label*/
 
 
 /*Symmetry-related stuff*/
@@ -97,6 +109,13 @@ EXTERN int nirreps;                 /*Number of irreducible representations in t
 
 EXTERN int num_allatoms;            /*Total number of all atoms (including dummies)*/
 EXTERN int num_atoms;               /*Total number of atoms*/
+EXTERN int nfragments;              /*Number of molecular fragments in input to read*/
+EXTERN int *frag_num_atoms;         /*Total number of atoms in each fragment*/
+EXTERN int *frag_num_allatoms;      /*Total number of all atoms (including dummies) in each fragment*/
+EXTERN int *frag_atom;              /* a fragment number -> first atom lookup array */
+EXTERN int *frag_allatom;              /* a fragment number -> first atom lookup array */
+EXTERN int *nref_per_fragment;      /* number of reference points on each fragment */
+EXTERN double ***ref_pts_lc;        /* coefficients that determine reference points on each fragment */
 EXTERN int num_uniques;             /*Number of unique atoms*/
 EXTERN int num_shells;              /*Total number of shells*/
 EXTERN int num_unique_shells;       /*Number of unique shells*/
@@ -204,7 +223,7 @@ EXTERN int **xexp_ao, **yexp_ao, **zexp_ao;
  ----------------------*/
 
 /*array of structures for z-mat entry*/
-struct z_entry* z_geom;          
+EXTERN struct z_entry* z_geom;          
 
 /*-----------------------------------------------
   Hack to allow MO projection onto the new basis
@@ -271,3 +290,7 @@ typedef struct {
 } GTOs_t;
 
 EXTERN GTOs_t GTOs;
+
+}} // namespace psi::input
+
+#endif // header guard
