@@ -1,5 +1,11 @@
+/*! \file
+    \ingroup INTDER
+    \brief Enter brief description of file here 
+*/
 #include "atom.h"
 
+using namespace psi::intder;
+
 Atom::Atom(int an, double aw, double ax, double ay, double az) 
     : Cartesian(ax, ay, az)
 {
