@@ -1,8 +1,14 @@
-#ifndef __atom_h
-#define __atom_h
+/*! \file
+    \ingroup INTDER
+    \brief Enter brief description of file here 
+*/
+#ifndef _psi_bin_intder_atom_h_
+#define _psi_bin_intder_atom_h_
 
 #include "cartesian.h"
 
+namespace psi { namespace intder {
+
 class Atom : public Cartesian
 {
 public:
@@ -23,5 +29,7 @@ public:
     { atomicWeight = aw; }
 };
 
-#endif
+}} // namespace psi::intder
+
+#endif // header guard
 
