@@ -1,5 +1,11 @@
-#ifndef __bmat_h
-#define __bmat_h
+/*! \file
+    \ingroup INTDER
+    \brief Enter brief description of file here 
+*/
+#ifndef _psi_bin_intder_bmat_h_
+#define _psi_bin_intder_bmat_h_
+
+namespace psi { namespace intder {
 
 class BMat
 {
@@ -26,4 +32,6 @@ public:
   void print_BMat();
 };
 
-#endif
+}} // namespace psi::intder
+
+#endif // header guard
