@@ -1,6 +1,12 @@
-#include <math.h>
+/*! \file
+    \ingroup INTDER
+    \brief Enter brief description of file here 
+*/
+#include <cmath>
 #include "cartesian.h"
 
+using namespace psi::intder;
+
 double Cartesian::Distance(Cartesian& B)
 {
   double result = 0.0;
