@@ -1,3 +1,7 @@
+/*! \file
+    \ingroup INTDER
+    \brief Enter brief description of file here 
+*/
 #include "intco.h"
 #include "params.h"
 #include "displacements.h"
@@ -6,24 +10,24 @@
 #define EXTERN
 #include "globals.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cmath>
 
-extern "C" {
-  #include <libciomr/libciomr.h>
-  #include <libipv1/ip_lib.h>
-  #include <libpsio/psio.h>
-  #include <physconst.h>
-  #include <psifiles.h>
+#include <libciomr/libciomr.h>
+#include <libipv1/ip_lib.h>
+#include <libpsio/psio.h>
+#include <physconst.h>
+#include <psifiles.h>
 
-//  extern FILE *outfile;
-};
+using namespace psi::intder;
 
+namespace psi { namespace intder {
 extern InternalCoordinates gIntCo;
 extern Params gParams;
 extern Displacements gDisplacements;
 extern BMat gBMat;
+}}
 
 void InternalCoordinate::printInfo()
 {
