@@ -1,9 +1,15 @@
-#ifndef __molecule_h
-#define __molecule_h
+/*! \file
+    \ingroup INTDER
+    \brief Enter brief description of file here 
+*/
+#ifndef _psi_bin_intder_molecule_h_
+#define _psi_bin_intder_molecule_h_
 
 #include "atom.h"
 #include <vector>
 
+namespace psi { namespace intder {
+
 class Molecule
 {
   std::vector<Atom> vectorAtoms;
@@ -20,5 +26,7 @@ public:
   Atom* atom(int an);
 };
 
-#endif
+}} // namespace psi::intder
+
+#endif // header guard
 
