@@ -1,3 +1,9 @@
+/*! \file
+    \ingroup MP2
+    \brief Enter brief description of file here 
+*/
+#ifndef _psi_src_bin_mp2_params_h_
+#define _psi_src_bin_mp2_params_h_
 struct params {
   int ref;
   char *wfn;
@@ -14,6 +20,8 @@ struct params {
   long int memory;
   int semicanonical;
   int scs;
-  double scs_scale_s;
-  double scs_scale_t;
+  double scs_scale_os;
+  double scs_scale_ss;
 };
+
+#endif /* Header guard */
