@@ -1,3 +1,11 @@
+/*! \file
+    \ingroup OEPROP
+    \brief Enter brief description of file here 
+*/
+
+#ifndef _psi_bin_oeprop_globals_h_
+#define _psi_bin_oeprop_globals_h_
+
 #define MAXMP 3         /* Up to octopole moments can be computed */
 #define EPS 1.0E-17     /* Absolute precision in computing Fm(t)
                            (see recursion:calc_fij() ) */
@@ -25,6 +33,8 @@
 				   vectors */
 #define PRINTDIPCOMPLEVEL 2	/* Printing level to print out contributions
 				   to electric dipole moment */
+#define PRINTDARWINCOMPLEVEL 2	/* Printing level to print out contributions
+				   to Darwin term */
 #define MAXDENSGRAD 3.0		/* Cutoff on the density gradient */
 
 #ifdef EXTERN
@@ -34,9 +44,12 @@
 # define EXTERN
 #endif
 
+namespace psi { namespace oeprop {
 
-EXTERN FILE *infile,*outfile;
-EXTERN char *psi_file_prefix;
+extern "C" {
+  EXTERN FILE *infile,*outfile;
+  EXTERN char *psi_file_prefix;
+}
 EXTERN int *ioff;
 EXTERN double df[MAXFACT*2];
 
@@ -195,6 +208,7 @@ EXTERN double *ahfsxx, *ahfsyy, *ahfszz,
               *ahfsxy, *ahfsxz, *ahfsyz;  /* Dipole-dipole contributions to the hyperfine coupling constants */
 EXTERN double *edens, *sdens;   /* Electron and spin densities at the nuclei */
 EXTERN double massveloc, darw;  /* First-order relativistic corrections to the energy */
+EXTERN double *darw_per_atom; /* atomic contributions to one-electron Darwin term */
 EXTERN double **grid_pts;	/* Scalar property (electrostatic potential, electron density, density gradient magnitude, Laplacian)
 				   values on a 2d grid */
 EXTERN double **grid_vecX, **grid_vecY, **grid_vecZ;    /* Components of vector properties (density gradient,
@@ -209,3 +223,9 @@ EXTERN double **nmo_ao;		/* Natural orbitals in the AO basis */
 EXTERN int **connectivity;    /* A matrix of flags whether a bong exists between two atoms */
 EXTERN char *wfn;             /* wavefunction type */
 EXTERN char *ref;             /* reference type */
+EXTERN int update_energy_with_MVD; /* update energy in file 1? for SCF_MVD optimizations */
+EXTERN double fine_structure_alpha; /* multiply relativisitic terms by this */
+
+}} // namespace psi::oeprop
+
+#endif // header guard
