@@ -1,27 +1,25 @@
-/*** cartesians.cc : contains member functions for cartesian class ***/
+/*! \file
+    \ingroup OPTKING
+    \brief cartesians.cc : contains member functions for cartesian class
+*/
 
-#if HAVE_CMATH
-# include <cmath>
-#else
-# include <math.h>
-#endif
+#include <cmath>
 
-extern "C" {
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 #include <libciomr/libciomr.h>
 #include <libipv1/ip_lib.h>
 #include <libchkpt/chkpt.h>
 #include <physconst.h>
 #include <masses.h>
-}
 
 #define EXTERN
 #include "opt.h"
 #include "cartesians.h"
 #undef EXTERN
 
+namespace psi { namespace optking {
 
 /*** FORCES returns forces in cartesian coordinates in aJ/Ang ***/ 
 double *cartesians:: get_forces() {
@@ -71,7 +69,13 @@ cartesians::cartesians() {
     ||(optinfo.mode == MODE_DISP_FREQ_GRAD_CART) || (optinfo.mode == MODE_FREQ_GRAD_CART)
     ||(optinfo.mode == MODE_DISP_FREQ_ENERGY_CART) || (optinfo.mode == MODE_FREQ_ENERGY_CART)
     )
-      energy = chkpt_rd_etot();
+
+  //ACS (11/06) Allow external programs to be used
+  if(optinfo.external_energies){
+    energy = 0.0;
+  }else{
+    energy = chkpt_rd_etot();
+  }
 
   zvals = chkpt_rd_zvals();
   chkpt_close();
@@ -197,6 +201,7 @@ cartesians::cartesians() {
  *   11        coord, grad                           file11.dat
  *   32        fcoord (implicitly coord)             chkpt
  *   12        fatomic_symb, fcoord                  fp_out
+ *   13        fatomic_symb, fcoord ANGSTROM         fp_out
  * disp_label is only used for geom.dat writing ***/
 
 void cartesians :: print(int print_flag, FILE *fp_out, int new_geom_file,
@@ -304,36 +309,35 @@ void cartesians :: print(int print_flag, FILE *fp_out, int new_geom_file,
 
     fprintf(outfile,"\nGeometry written to chkpt\n");
 
-    double **geom;
-    geom = block_matrix(nallatom,3);
+  //  double **geom;
+  //  geom = block_matrix(nallatom,3);
   //  for (i=0; i<nallatom; ++i)
-    for (i=0; i<natom; ++i)
-      for (j=0; j<3; ++j)
-        geom[optinfo.to_dummy[i]][j] = coord[3*i+j];
+  //  for (i=0; i<natom; ++i)
+  //    for (j=0; j<3; ++j)
+  //      geom[optinfo.to_dummy[i]][j] = coord[3*i+j];
     chkpt_init(PSIO_OPEN_OLD);
-    chkpt_wt_fgeom(geom);
+    chkpt_wt_fgeom(&fcoord);
     chkpt_close();
-    free_block(geom);
-
-    /*
-    double **tmp2d;
-    chkpt_init(PSIO_OPEN_OLD);
-    tmp2d = chkpt_rd_fgeom();
-    chkpt_close();
-    for (i=0; i<nallatom; ++i)
-      for (j=0; j<3; ++j)
-        fprintf(outfile,"%15.10lf\n", tmp2d[i][j]);
-    free_block(tmp2d);
-    */
+  //  free_block(geom);
 
   }
   else if (print_flag == 12) { 
     for (i = 0; i < natom; ++i) {
       x = coord[++cnt]; y = coord[++cnt]; z = coord[++cnt];
       zval_to_symbol(atomic_num[i],sym);
-      fprintf(fp_out,"  (%3s%15.10f%15.10f%15.10f )\n",sym,x,y,z);
+      fprintf(fp_out,"  (%3s %15.10f %15.10f %15.10f )\n",sym,x,y,z);
+    }
+  }
+  else if (print_flag == 13) { 
+    for (i = 0; i < natom; ++i) {
+      x = coord[++cnt] * _bohr2angstroms; 
+      y = coord[++cnt] * _bohr2angstroms; 
+      z = coord[++cnt] * _bohr2angstroms;
+      zval_to_symbol(atomic_num[i],sym);
+      fprintf(fp_out,"  (%3s %15.10f %15.10f %15.10f )\n",sym,x,y,z);
     }
   }
   return;
 }
 
+}} /* namespace psi::optking */
