@@ -1,25 +1,21 @@
-// This function forms a set of delocalized, symmetry-adapted
-// internal coordinates, given a set of simples and their
-// s-vectors.  The new coordinates will not mix coordinates of
-// different types if mix_types == 1
+/*! \file
+    \ingroup OPTKING
+    \brief This function forms a set of delocalized, symmetry-adapted
+     internal coordinates, given a set of simples and their
+     s-vectors.  The new coordinates will not mix coordinates of
+     different types if mix_types == 1
+*/
 
-#if HAVE_CMATH
-# include <cmath>
-#else
-# include <math.h>
-#endif
-
-extern "C" {
-#include <stdio.h>
+#include <cmath>
+#include <cstdio>
 #include <libchkpt/chkpt.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <physconst.h>
 #include <libciomr/libciomr.h>
 #include <libipv1/ip_lib.h>
 #include <libpsio/psio.h>
 #include <psifiles.h>
-}
 
 #define EXTERN
 #include "opt.h"
@@ -28,8 +24,9 @@ extern "C" {
 #include "internals.h"
 #include "salc.h"
 
-extern double **irrep(internals &simples, double **evectst);
+namespace psi { namespace optking {
 
+extern double **irrep(internals &simples, double **evectst);
 void rm_rotations(internals &simples, cartesians &carts, int &num_nonzero, double **evects);
 
 void delocalize(internals &simples, cartesians &carts) {
@@ -312,8 +309,6 @@ void delocalize(internals &simples, cartesians &carts) {
   return;
 }
 
-double repulsion(double *fatomic_num, double *geom);
-
 // removes rotations - returns number of rotations removed
 void rm_rotations(internals &simples, cartesians &carts, int &num_nonzero,
     double **evects) {
@@ -328,7 +323,7 @@ void rm_rotations(internals &simples, cartesians &carts, int &num_nonzero,
 
   coord = carts.get_coord();
 
-  energy = repulsion(fatomic_num,coord);
+  energy = nuclear_repulsion(fatomic_num,coord);
 
   disp_coord = new double [3*optinfo.natom];
   for (ivect=0; ivect<num_nonzero; ++ivect) {
@@ -383,7 +378,7 @@ void rm_rotations(internals &simples, cartesians &carts, int &num_nonzero,
         disp_coord[3*d+k] += scale * evects[cnt][ivect] * simples.out.get_D(i);
       }
     }
-    disp_energy = repulsion(fatomic_num, disp_coord);
+    disp_energy = nuclear_repulsion(fatomic_num, disp_coord);
     // fprintf(outfile,"dispenergy - energy: %16.12lf\n",disp_energy - energy);
     if (fabs(disp_energy - energy) < rot_tol) {
       fprintf(outfile,"rotational coordinate eliminated");
@@ -400,21 +395,5 @@ void rm_rotations(internals &simples, cartesians &carts, int &num_nonzero,
   return;
 }
 
-double repulsion(double *fatomic_num, double *coord) {
-  int i, j, dim;
-  double dist, tval = 0.0;
-
-  dim = optinfo.natom;
-  for (i=0; i<dim; ++i)
-    for (j=0; j<i; ++j) {
-      dist = sqrt(
-          SQR(coord[3*i+0]-coord[3*j+0])
-          + SQR(coord[3*i+1]-coord[3*j+1])
-          + SQR(coord[3*i+2]-coord[3*j+2]) );
-
-      tval += fatomic_num[i]*fatomic_num[j] / dist;
-    }
-  fprintf(outfile,"returning repulsion: %15.10lf \n", tval);
-  return tval;
-}
+}} /* namespace psi::optking */
 
