@@ -1,25 +1,40 @@
-/* DISP_FREQ_ENERGY_CART makes symmetry-adapted cartesian coordinates and displaces
-   along them to setup frequencies by energy points */
+/*! \file
+    \ingroup OPTKING
+    \brief 
+ DISP_FREQ_ENERGY_CART makes symmetry-adapted cartesian coordinates and displaces
+   along them to setup frequencies by energy points
+Formulas for finite differences
+3-point - diagonal
+  O(1/h^2): [f(1,0) + f(-1,0) - 2f(0,0)]/(h^2)
+   [which is same as : [f(2,0) + f(-2,0) - 2f(0,0)]/(4h^2)
+3-point - off-diagonal
+  O(1/h^2): old-way: [f(1,1) - f(1,-1) - f(-1,1) + f(-1,-1)]/(4h^2)
+  O(1/h^2): new-way: [f(1,1)+f(-1,-1)+2f(0,0) -f(1,0) -f(-1,0) -f(0,1) -f(0,-1)]/(2h^2)
 
-#if HAVE_CMATH
-# include <cmath>
-#else
-# include <math.h>
-#endif
+5-point formula - diagonal
+  O(1/h^4): [-f(-2,0) + 16f(-1,0) + 16f(1,0) - f(2,0) - 30f(0,0)] / (12h^2)
+5-point formula - off-diagonal
+  O(1/h^4): old-way [ 1f(-2,-2) - 8f(-1,-2) + 8f(+1,-2) - 1f(+2,-2) - 8f(-2,-1)
+  + 64f(-1,-1) - 64f(+1,-1) + 8f(+2,-1) + 8f(-2,+1) - 64f(-1,+1) + 64f(+1,+1)
+ - 8f(+2,+1) - 1f(-2,+2) + 8f(-1,+2) - 8f(+1,+2) + 1f(+2,+2) / (144h^2)
+  O(1/h^4): new-way [ -1f(-1,-2) - 1f(-2,-1) + 9f(-1,-1) - 1f(+1,-1)
+    - 1f(-1,1) + 9f(+1,+1) - 1f(+2,+1) - 1f(1,2)
+    + 1f(-2,0) - 7f(-1,0)  - 7f(+1,0) + 1f(+2,0)
+    + 1f(0,-2) - 7f(0,-1)  - 7f(0,+1) + 1f(0,+2) + 12f(0,0)]/(12h^2)
+*/
 
-extern "C" {
-#include <stdio.h>
+#include <cmath>
+#include <cstdio>
 #include <libchkpt/chkpt.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
+#include <cstdlib>
+#include <cstring>
+#include <cctype>
 #include <libciomr/libciomr.h>
 #include <libqt/qt.h>
 #include <libipv1/ip_lib.h>
 #include <physconst.h>
 #include <libpsio/psio.h>
 #include <psifiles.h>
-}
 
 #define EXTERN
 #include "opt.h"
@@ -29,6 +44,8 @@ extern "C" {
 #include "salc.h"
 #include "bond_lengths.h"
 
+namespace psi { namespace optking {
+
 extern int get_irrep_xyz( double **cartrep, int xyz);
 extern int check_coordinates(int natom, double *coord, double *masses, double *Zvals,
     int *ndisp_small, double ***disp_small);
@@ -171,12 +188,6 @@ int disp_freq_energy_cart(cartesians &carts)
     }
   }
   nconstraints = cnt+1;
-  /*
-  if (print) {
-    fprintf(outfile,"Normalized constraints\n");
-    print_mat(constraints,nconstraints,3*natom,outfile);
-  }
-  */
 
   /* Orthogonalize rotations and translations exactly-is this ever necessary?*/
   constraints_ortho = block_matrix(nconstraints,3*natom);
@@ -187,12 +198,6 @@ int disp_freq_energy_cart(cartesians &carts)
     for (j=0; j<3*natom; ++j)
       constraints[i][j] = constraints_ortho[i][j];
   free_block(constraints_ortho);
-  /*
-  if (print) {
-    fprintf(outfile,"Orthogonal constraints\n");
-    print_mat(constraints,nconstraints,3*natom,outfile);
-  }
-  */
 
   /**** Form symmetry-adapted cartesian vectors ****/
   salc_orig = (double ***) malloc(nirreps*sizeof(double **));
@@ -290,7 +295,7 @@ int disp_freq_energy_cart(cartesians &carts)
   if (print) {
     for (irrep=0; irrep < nirreps; ++irrep)
       if (nsalc[irrep]) {
-        fprintf(outfile,"Projected Cartesian Displacements, irrep %d\n", irrep);
+        fprintf(outfile,"Symmetry Adapted Cartesian Coordinates, irrep %d\n", irrep);
         print_mat(salc[irrep], nsalc[irrep], 3*natom, outfile);
       }
   }
@@ -298,7 +303,6 @@ int disp_freq_energy_cart(cartesians &carts)
   check_coordinates(natom,coord,masses,Zvals,nsalc,salc);
 
   /* determine number of displacements */
-  /* 1/h^2 * (f(1,0) + f(-1,0) + 2f(0,0) ) */
   ndisp_all = 0;
   ndisp = init_int_array(nirreps);
   for (irrep=0; irrep<nirreps; ++irrep) {
@@ -319,9 +323,9 @@ int disp_freq_energy_cart(cartesians &carts)
 
     /* off-diagonal displacements */
     if (optinfo.points == 3)
-      ndisp[irrep] += 4 * nsalc[irrep] * (nsalc[irrep] - 1) / 2;
+      ndisp[irrep] += 2 * nsalc[irrep] * (nsalc[irrep] - 1) / 2;
     else if (optinfo.points == 5)
-      ndisp[irrep] += 16 * nsalc[irrep] * (nsalc[irrep] - 1) / 2;
+      ndisp[irrep] += 8 * nsalc[irrep] * (nsalc[irrep] - 1) / 2;
 
     ndisp_all += ndisp[irrep];
   }
@@ -381,62 +385,64 @@ int disp_freq_energy_cart(cartesians &carts)
     /* add off-diagonal displacements */
 
     for (i=0; i<nsalc[irrep]; ++i) {
-      for (j=i+1; j<nsalc[irrep]; ++j) {
+      for (j=0; j<i; ++j) {
         if (optinfo.points == 3) {
           for (k=0; k < 3*natom; ++k) {
             geoms[irrep][cnt+0][k] += ( + salc[irrep][i][k] + salc[irrep][j][k] )
               * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+1][k] += ( + salc[irrep][i][k] - salc[irrep][j][k] )
-              * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+2][k] += ( - salc[irrep][i][k] + salc[irrep][j][k] )
-              * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+3][k] += ( - salc[irrep][i][k] - salc[irrep][j][k] )
+            geoms[irrep][cnt+1][k] += ( - salc[irrep][i][k] - salc[irrep][j][k] )
               * optinfo.disp_size / sqrt(masses[k]);
           }
-          cnt += 4;
+          cnt += 2;
         }
         else if (optinfo.points == 5) {
           for (k=0; k < 3*natom; ++k) {
-            geoms[irrep][cnt+0][k] += ( - 2.0 * salc[irrep][i][k] - 2.0 * salc[irrep][j][k] )
+            geoms[irrep][cnt+0][k] += ( - 1.0 * salc[irrep][i][k] - 2.0 * salc[irrep][j][k] )
               * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+1][k] += ( - 1.0 * salc[irrep][i][k] - 2.0 * salc[irrep][j][k] )
+            geoms[irrep][cnt+1][k] += ( - 2.0 * salc[irrep][i][k] - 1.0 * salc[irrep][j][k] )
               * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+2][k] += ( + 1.0 * salc[irrep][i][k] - 2.0 * salc[irrep][j][k] )
+            geoms[irrep][cnt+2][k] += ( - 1.0 * salc[irrep][i][k] - 1.0 * salc[irrep][j][k] )
               * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+3][k] += ( + 2.0 * salc[irrep][i][k] - 2.0 * salc[irrep][j][k] )
+            geoms[irrep][cnt+3][k] += ( + 1.0 * salc[irrep][i][k] - 1.0 * salc[irrep][j][k] )
               * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+4][k] += ( - 2.0 * salc[irrep][i][k] - 1.0 * salc[irrep][j][k] )
+            geoms[irrep][cnt+4][k] += ( - 1.0 * salc[irrep][i][k] + 1.0 * salc[irrep][j][k] )
               * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+5][k] += ( - 1.0 * salc[irrep][i][k] - 1.0 * salc[irrep][j][k] )
+            geoms[irrep][cnt+5][k] += ( + 1.0 * salc[irrep][i][k] + 1.0 * salc[irrep][j][k] )
               * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+6][k] += ( + 1.0 * salc[irrep][i][k] - 1.0 * salc[irrep][j][k] )
+            geoms[irrep][cnt+6][k] += ( + 2.0 * salc[irrep][i][k] + 1.0 * salc[irrep][j][k] )
               * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+7][k] += ( + 2.0 * salc[irrep][i][k] - 1.0 * salc[irrep][j][k] )
-              * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+8][k] += ( - 2.0 * salc[irrep][i][k] + 1.0 * salc[irrep][j][k] )
-              * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+9][k] += ( - 1.0 * salc[irrep][i][k] + 1.0 * salc[irrep][j][k] )
-              * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+10][k] += ( + 1.0 * salc[irrep][i][k] + 1.0 * salc[irrep][j][k] )
-              * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+11][k] += ( + 2.0 * salc[irrep][i][k] + 1.0 * salc[irrep][j][k] )
-              * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+12][k] += ( - 2.0 * salc[irrep][i][k] + 2.0 * salc[irrep][j][k] )
-              * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+13][k] += ( - 1.0 * salc[irrep][i][k] + 2.0 * salc[irrep][j][k] )
-              * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+14][k] += ( + 1.0 * salc[irrep][i][k] + 2.0 * salc[irrep][j][k] )
-              * optinfo.disp_size / sqrt(masses[k]);
-            geoms[irrep][cnt+15][k] += ( + 2.0 * salc[irrep][i][k] + 2.0 * salc[irrep][j][k] )
+            geoms[irrep][cnt+7][k] += ( + 1.0 * salc[irrep][i][k] + 2.0 * salc[irrep][j][k] )
               * optinfo.disp_size / sqrt(masses[k]);
           }
-          cnt += 16;
+          cnt += 8;
         }
       }
     }
   }
   free(masses);
 
+  if(optinfo.external_energies){
+    int counter = 1;
+    FILE *fp_dispcart = fopen("dispcart", "w");
+    // ACS (11/06) Print the displaced and reference geometry for external programs
+    // Use 1 based counting, and remember that the first "displacement" is the reference itself
+    fprintf(fp_dispcart,"%d\n",counter++);
+    for(int n = 0; n < carts.get_natom(); n++){
+      fprintf(fp_dispcart,"%16.10lf %16.10lf %16.10lf\n",coord[3*n],coord[3*n+1],coord[3*n+2]);
+    }
+
+    for (irrep=0; irrep<nirreps; ++irrep) {
+      for(int disp = 0; disp< ndisp[irrep]; disp++){
+        fprintf(fp_dispcart,"%d\n",counter++);
+        for(int n = 0; n < carts.get_natom(); n++){
+          fprintf(fp_dispcart,"%16.10lf %16.10lf %16.10lf\n",
+            geoms[irrep][disp][3*n],geoms[irrep][disp][3*n+1],geoms[irrep][disp][3*n+2]);
+        }
+      }
+    }
+    fclose(fp_dispcart);
+  }
+
   /**** write out info to PSIF_OPTKING, geoms and coordinates in irrep order ****/
   open_PSIF();
 
@@ -454,8 +460,8 @@ int disp_freq_energy_cart(cartesians &carts)
     if (ndisp[irrep]) {
       psio_write(PSIF_OPTKING, "OPT: Displaced geometries",
           (char *) &(geoms[irrep][0][0]), ndisp[irrep]*3*natom*sizeof(double), next, &next);
-fprintf(outfile,"Displaced Geometries of irrep %d.\n",irrep);
-print_mat(geoms[irrep],ndisp[irrep],3*natom,outfile);
+//fprintf(outfile,"Displaced Geometries of irrep %d.\n",irrep);
+//print_mat(geoms[irrep],ndisp[irrep],3*natom,outfile);
     }
     free_block(geoms[irrep]);
   }
@@ -488,17 +494,6 @@ print_mat(geoms[irrep],ndisp[irrep],3*natom,outfile);
   disp_e = init_array(ndisp_all);
   optinfo.micro_iteration = 0;
 
-  /*
-  ndisp_all = 8;
-  ndisp[1] = 0;
-  ndisp[2] = 0;
-  ndisp[3] = 0;
-  nsalc_all = 4;
-  nsalc[1] = 0;
-  nsalc[2] = 0;
-  nsalc[3] = 0;
-  */
-
   psio_write_entry(PSIF_OPTKING, "OPT: Displaced energies",
       (char *) &(disp_e[0]), ndisp_all*sizeof(double));
   psio_write_entry(PSIF_OPTKING, "OPT: Reference geometry",
@@ -533,3 +528,5 @@ print_mat(geoms[irrep],ndisp[irrep],3*natom,outfile);
   return(ndisp_all);
 }
 
+}} /* namespace psi::optking */
+
