@@ -1,25 +1,21 @@
-/*** ENERGY_SAVE.CC Rollin King, 2002 ***/
-// function executes if optinfo.mode == MODE_GRAD_SAVE
+/*! \file
+    \ingroup OPTKING
+    \brief ENERGY_SAVE.CC Rollin King, 2002 
+     function executes if optinfo.mode == MODE_GRAD_SAVE
+*/
 
-#if HAVE_CMATH
-# include <cmath>
-#else
-# include <math.h>
-#endif
-
-extern "C" {
-#include <stdio.h>
+#include <cmath>
+#include <cstdio>
 #include <libchkpt/chkpt.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
+#include <cstdlib>
+#include <cstring>
+#include <cctype>
 #include <libciomr/libciomr.h>
 #include <libipv1/ip_lib.h>
 #include <libpsio/psio.h>
 #include <physconst.h>
 #include <psifiles.h>
 #include <ccfiles.h>
-}
 
 #define EXTERN
 #include "opt.h"
@@ -27,6 +23,8 @@ extern "C" {
 #include "cartesians.h"
 #include "internals.h"
 
+namespace psi { namespace optking {
+
 void energy_save(cartesians &carts) {
   int i,j,dim_carts,total_num_disps;
   double energy, *micro_e, *micro_grad, *grad;
@@ -102,3 +100,6 @@ void energy_save(cartesians &carts) {
 
   return ;
 }
+
+}} /* namespace psi::optking */
+
