@@ -1,22 +1,19 @@
-/*** GET_SYMINFO   gets symmetry info from chkpt and char_table.c ***/ 
+/*! \file
+    \ingroup OPTKING
+    \brief GET_SYMINFO: gets symmetry info from chkpt and char_table.c
+*/
 
-#if HAVE_CMATH
-# include <cmath>
-#else
-# include <math.h>
-#endif
-
-extern "C" {
-  #include <stdio.h>
-  #include <stdlib.h>
-  #include <string.h>
-  #include <ctype.h>
-  #include <libchkpt/chkpt.h>
-  #include <libciomr/libciomr.h>
-  #include <libipv1/ip_lib.h>
-  #include <physconst.h>
-  #include <libpsio/psio.h>
-}
+#include <cmath>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cctype>
+#include <libqt/qt.h>
+#include <libchkpt/chkpt.h>
+#include <libciomr/libciomr.h>
+#include <libipv1/ip_lib.h>
+#include <physconst.h>
+#include <libpsio/psio.h>
 
 #define EXTERN
 #include "opt.h"
@@ -24,15 +21,15 @@ extern "C" {
 #include "cartesians.h"
 #include "internals.h"
 
-extern "C" int **get_char_table(char *symmetry);
-extern "C"  char **get_symm_ops(char *symmetry);
-extern "C" int *get_ops_in_class(char *ptgrp, int nirreps);
-//extern "C" void swap(int *a, int *b);
-//extern "C" void swap_tors(int *a, int *b, int *c, int *d);
+namespace psi { namespace optking {
+
+extern int **get_char_table(char *symmetry);
+extern char **get_symm_ops(char *symmetry);
+extern int *get_ops_in_class(char *ptgrp, int nirreps);
 
 void get_syminfo(internals &simples) {
   int a, b, c, d, aa, bb, cc, dd, i, j, sign, natom;
-  int id, intco_type, sub_index, ops,linval;
+  int id, intco_type, sub_index, sub_index2, ops,linval;
   int nallatom;
 
   nallatom = optinfo.nallatom;
@@ -55,8 +52,10 @@ void get_syminfo(internals &simples) {
   syminfo.irrep_lbls = chkpt_rd_irr_labs();
   chkpt_close();
 
+  // abort if group label is greater than 3 characters
   j = strlen(syminfo.symmetry);
-  strncpy(ptgrp,syminfo.symmetry,j);
+  if (j > 3) abort();
+  strncpy(ptgrp,syminfo.symmetry,4);
   for ( ;j<3;++j)
     ptgrp[j] = ' ';
   ptgrp[3] = '\0';
@@ -108,7 +107,7 @@ void get_syminfo(internals &simples) {
   // include dymmy atoms, only is symmetry sets of dummy atoms were generated
   for (i=0;i<simples.get_num();++i) {
     id = simples.index_to_id(i);
-    simples.locate_id(id,&intco_type,&sub_index);
+    simples.locate_id(id,&intco_type,&sub_index,&sub_index2);
     if (intco_type == STRE_TYPE) {
       a = simples.stre.get_A(sub_index);
       b = simples.stre.get_B(sub_index);
@@ -236,3 +235,5 @@ void get_syminfo(internals &simples) {
   return;
 }
 
+}} /* namespace psi::optking */
+
