@@ -1,23 +1,19 @@
-/*** GRAD_ENERGY computes a file11 entry from energies in chkpt Rollin King, 2002 ***/ 
+/*! \file
+    \ingroup OPTKING
+    \brief GRAD_ENERGY computes a file11 entry from energies in chkpt Rollin King, 2002
+*/
 
-#if HAVE_CMATH
-# include <cmath>
-#else
-# include <math.h>
-#endif
-
-extern "C" {
-#include <stdio.h>
+#include <cmath>
+#include <cstdio>
 #include <libchkpt/chkpt.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
+#include <cstdlib>
+#include <cstring>
+#include <cctype>
 #include <libciomr/libciomr.h>
 #include <libipv1/ip_lib.h>
 #include <physconst.h>
 #include <libpsio/psio.h>
 #include <psifiles.h>
-}
 
 #define EXTERN
 #include "opt.h"
@@ -28,6 +24,8 @@ extern "C" {
 #include "bond_lengths.h"
 #define MAX_LINE 132
 
+namespace psi { namespace optking {
+
 double **compute_B(internals &simples, salc_set &symm);
 
 void grad_energy(cartesians &carts, internals &simples, salc_set &symm) {
@@ -60,9 +58,17 @@ void grad_energy(cartesians &carts, internals &simples, salc_set &symm) {
     fp_energy_dat = fopen("energy.dat", "r");
     rewind (fp_energy_dat);
     line1 = new char[MAX_LINE+1];
-    for (i=0; i<num_disps; ++i) {
-      fgets(line1, MAX_LINE, fp_energy_dat);
-      sscanf(line1, "%lf", &(energies[i]));
+    // ACS (11/06) Allow external program to be used to compute energies
+    if(optinfo.external_energies){
+      /* Read the first energy and dump it as the reference energy */
+      double temp;
+      fscanf(fp_energy_dat,"%lf",&temp);
+      open_PSIF();
+      psio_write_entry(PSIF_OPTKING, "OPT: Reference energy",(char *) &(temp), sizeof(double));
+      close_PSIF();
+    }
+    for (i=0; i<num_disps; i++) {
+      fscanf(fp_energy_dat,"%lf",&(energies[i]));
     }
     fclose(fp_energy_dat);
     delete [] line1;
@@ -79,7 +85,7 @@ void grad_energy(cartesians &carts, internals &simples, salc_set &symm) {
   for (i=0;i<symm.get_num();++i) {
     fprintf(outfile,"Coordinate %d: ",i);
     for (j=0;j<optinfo.points-1;++j)
-      fprintf(outfile,"%15.10lf",energies[++cnt]);
+      fprintf(outfile,"%15.10lf ",energies[++cnt]);
     fprintf(outfile,"\n");
   }
   fflush(outfile);
@@ -179,3 +185,5 @@ for (i=0;i<symm.get_num();++i)
   */
 }
 
+}} /* namespace psi::optking */
+
