@@ -1,20 +1,17 @@
-/*** INTERNALS.CC member functions for internals class ***/ 
+/*! \file
+    \ingroup OPTKING
+    \brief INTERNALS.CC member functions for internals class
+*/
 
-#if HAVE_CMATH
-# include <cmath>
-#else
-# include <math.h>
-#endif
-
-extern "C" {
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cmath>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 #include <libciomr/libciomr.h>
+#include <libqt/qt.h>
 #include <libipv1/ip_lib.h>
 #include <physconst.h>
 #include "bond_lengths.h"
-}
 
 #define EXTERN
 #include "opt.h"
@@ -22,13 +19,15 @@ extern "C" {
 #include "cartesians.h"
 #include "internals.h"
 
+namespace psi { namespace optking {
+
 int is_unique(int a, int b, int c, int d, int *aa, int *bb, int *cc, int *dd);
 
 /*** INTERNALS::INDEX_TO_ID
  * Converts the absolute optking index into the user-assigned id number ***/
 
 int internals :: index_to_id(int index) {
-  int i, count = -1, id = -1;
+  int i, I, count = -1, id = -1;
   for (i=0;i<stre.get_num();++i)
     if (++count == index) {id = stre.get_id(i); break;}
   for (i=0;i<bend.get_num();++i)
@@ -39,6 +38,10 @@ int internals :: index_to_id(int index) {
     if (++count == index) {id = out.get_id(i); break;}
   for (i=0;i<lin_bend.get_num();++i)
     if (++count == index) {id = lin_bend.get_id(i); break;}
+  /* we assume an id number of the fragment set plus the index 0-5 of the coordinate in the set */
+  for (i=0;i<frag.get_num();++i)
+    for (I=0;I<frag.get_dim(i);++I)
+      if (++count == index) {id = frag.get_id(i)+I; i=frag.get_num(); break;}
   //   fprintf(outfile,"index_to_id(%d): returning id = %d\n",index, id);
   return id;
 }
@@ -49,7 +52,7 @@ int internals :: index_to_id(int index) {
  * Converts the user-assigned id number into an absolute optking index ***/ 
 
 int internals :: id_to_index(int id) {
-  int i, count = 0, index = -1, found = 0;
+  int i, I, count = 0, index = -1, found = 0;
   for (i=0;i<stre.get_num();++i,++count)
     if (id == stre.get_id(i)) {index = count; ++found;}
   for (i=0;i<bend.get_num();++i,++count)
@@ -60,6 +63,11 @@ int internals :: id_to_index(int id) {
     if (id == out.get_id(i)) {index = count; ++found;}
   for (i=0;i<lin_bend.get_num();++i,++count)
     if (id == lin_bend.get_id(i)) {index = count; ++found;}
+  /* we assume an id number of the fragment set plus the index 0-5 of the coordinate in the set */
+  for (i=0;i<frag.get_num();++i)
+    for (I=0;I<frag.get_dim(i);++I,++count)
+      if (id == (frag.get_id(i)+I)) {index = count; ++found;}
+
   if (found == 0) {
     fprintf(outfile,"Error: Simple internal id not found.\n");
     exit(2);
@@ -78,8 +86,8 @@ int internals :: id_to_index(int id) {
  * Given the user-assigned id number, returns the type of internal
  and the subindex within that type ***/
 
-void internals :: locate_id(int id, int *intco_type, int *sub_index) {
-  int i, found = 0;
+void internals :: locate_id(int id, int *intco_type, int *sub_index, int *sub_index2) {
+  int I, i, j, found = 0;
   // fprintf(outfile,"locating id %d\n",id);
   for (i=0;i<stre.get_num();++i)
     if (stre.get_id(i) == id) {
@@ -101,6 +109,17 @@ void internals :: locate_id(int id, int *intco_type, int *sub_index) {
     if (lin_bend.get_id(i) == id) {
       ++found; *intco_type = LIN_BEND_TYPE; *sub_index = i;
     }
+
+  j=-1;
+  for (i=0;i<frag.get_num();++i) {
+    for (I=0;I<frag.get_dim(i);++I) {
+      ++j;
+      if ((frag.get_id(i)+I) == id) {
+        ++found; *intco_type = FRAG_TYPE; *sub_index = i; *sub_index2 = I;
+      }
+    }
+  }
+
   if (found == 0) {
     fprintf(outfile,"Error: Simple internal id not found.\n");
     exit(2);
@@ -114,25 +133,24 @@ void internals :: locate_id(int id, int *intco_type, int *sub_index) {
 }
 
 internals :: ~internals() {
-  // fprintf(stdout,"destructing internals\n");
   // Destructors for stre, bend, tors, out are called automatically
 }
 
-// minimal constructor
+/*** INTERNALS::INTERNALS minimal class constructor */
 internals :: internals(int *size_arr) : stre(size_arr[0]), bend(size_arr[1]),
-  tors(size_arr[2]), out(size_arr[3]), lin_bend(size_arr[4]) {
+  tors(size_arr[2]), out(size_arr[3]), lin_bend(size_arr[4]), frag(size_arr[5]) {
 }
 
-/*** INTERNALS::INTERNALS class constructor for internals ***/ 
-
+/*** INTERNALS::INTERNALS constructs internals from ip parsing ***/
 internals :: internals(cartesians& carts, int user_intcos)
-           : stre(), bend(), tors(), out(), lin_bend() {
+           : stre(), bend(), tors(), out(), lin_bend(), frag() {
 
-    int i,j,k,a,b,c,d,e,cnt,lin, type_count=0;
-    int cnt_stre, cnt_bend, cnt_tors, cnt_out, cnt_lin_bend;
-    int cnt_lin1_bend, cnt_lin2_bend;
+    int i,I,j,k,a,b,c,d,e,cnt,lin, type_count=0;
+    int cnt_stre, cnt_bend, cnt_tors, cnt_out, cnt_lin_bend, cnt_frag;
+    int cnt_lin1_bend, cnt_lin2_bend, na, nb;
+    double *v, dot;
     cnt_stre = cnt_bend = cnt_tors = cnt_out = cnt_lin_bend = 0;
-    cnt_lin1_bend = cnt_lin2_bend = 0;
+    cnt_lin1_bend = cnt_lin2_bend = cnt_frag = 0;
 
     for (cnt=1; cnt>=0; --cnt) { /* 1st time through we are just counting */
 
@@ -142,12 +160,14 @@ internals :: internals(cartesians& carts, int user_intcos)
         tors.set_num(cnt_tors);
         out.set_num(cnt_out);
         lin_bend.set_num(cnt_lin_bend);
+        frag.set_num(cnt_frag);
 
         stre.allocate(cnt_stre);
         bend.allocate(cnt_bend);
         tors.allocate(cnt_tors);
         out.allocate(cnt_out);
         lin_bend.allocate(cnt_lin_bend);
+        frag.allocate(cnt_frag);
       }
 
     if (user_intcos) {
@@ -279,6 +299,7 @@ internals :: internals(cartesians& carts, int user_intcos)
         }
       }
 
+      cnt_out = 0;
       if (ip_exist("OUT",0)) {
         i = 0;
         ip_count("OUT",&i,0);
@@ -305,16 +326,106 @@ internals :: internals(cartesians& carts, int user_intcos)
           }
         }
       }
-      else if(!ip_exist("OUT",0))
-        cnt_out = 0;
+
+      if (ip_exist("FRAG",0)) {
+        i = 0;
+        ip_count("FRAG",&i,0);
+        cnt_frag = i;
+
+        for(i=0; i<cnt_frag; ++i) {
+          ip_count("FRAG",&j,1,i);
+          if (j != 6) {
+            fprintf(outfile,"Fragment %d is of wrong dimension.\n",i+1);
+            exit(2);
+          }
+        }
+        if (!cnt) { // allocate memory for fragments
+          for(i=0; i<cnt_frag; ++i) {
+            // read ID number
+            ip_data("FRAG","%d",&a,2,i,0);
+            frag.set_id(i,a);
+
+            // read A_natom and B_natom
+            ip_count("FRAG",&na,2,i,2);
+            frag.set_A_natom(i,na);
+            ip_count("FRAG",&nb,2,i,3);
+            frag.set_B_natom(i,nb);
+
+            // check to make sure 3 reference points are specified for each fragment (for now)
+            ip_count("FRAG",&a,2,i,4);
+            ip_count("FRAG",&b,2,i,5);
+            if ( (a != 3) || (b != 3)) {
+              fprintf(outfile,"Fragment %d has weights of wrong dimension\n", i+1);
+              exit(2);
+            }
+            frag.set_A_P(i,3);
+            frag.set_B_P(i,3);
+
+            // allocate all extra memory for fragment
+            frag.allocate_one(i);
+
+            // read what coordinates are on
+            ip_count("FRAG",&a,2,i,1);
+            if (a != 6) throw("Coordinate-on (second) part of Fragment %d must have dimension 6.\n",i+1);
+            for (I=0; I<6;++I) {
+              ip_boolean("FRAG",&a,3,i,1,I);
+              frag.set_coord_on(i,I,a);
+            }
+
+            // read what atoms are in each fragment
+            for (j=0;j<na;++j) {
+              ip_data("FRAG","%d",&a,3,i,2,j);
+              frag.set_A_atom(i,j,a-1);  
+            }
+            for (j=0;j<nb;++j) {
+              ip_data("FRAG","%d",&b,3,i,3,j);
+              frag.set_B_atom(i,j,b-1); 
+            }
+
+            // read in weights for fragment A - make the absolute sum of the coefficients 1
+            v = new double[na];
+            for (j=0;j<3;++j) {
+              ip_count("FRAG",&a,3,i,4,j);
+              if (a != na) throw("Fragment A has weights of wrong dimension\n");
+              for (a=0;a<na;++a)
+                ip_data("FRAG","%lf",&(v[a]),4,i,4,j,a);
+              dot = 0.0;
+              for (a=0;a<na;++a)
+                dot += fabs(v[a]);
+              for (a=0;a<na;++a)
+                v[a] /= dot;
+              for (a=0;a<na;++a)
+                frag.set_A_weight(i,j,a,v[a]);
+            }
+            delete [] v;
+
+            // read in weights for fragment B - make the absolute sum of the coefficients 1
+            v = new double[nb];
+            for (j=0;j<3;++j) {
+              ip_count("FRAG",&b,3,i,5,j);
+              if (b != nb) throw("Fragment A has weights of wrong dimension\n");
+              for (b=0;b<nb;++b)
+                ip_data("FRAG","%lf",&(v[b]),4,i,5,j,b);
+              dot = 0.0;
+              for (b=0;b<nb;++b)
+                dot += fabs(v[b]);
+              for (b=0;b<nb;++b)
+                v[b] /= dot;
+              for (b=0;b<nb;++b)
+                frag.set_B_weight(i,j,b,v[b]);
+            }
+            delete [] v;
+          }
+        }
+      }
     }
     else {
 
       /* Generate simple internal coordinates from a cartesian geometry */
-      int *ioff, count, Z1, Z2, natom;
+      int count, Z1, Z2, natom;
       double **atom_dist, **coord_2d, tval;
       int **bonds, id_count=0;
-      int num_bonds, num_nobonds;
+      int num_bonds, num_nobonds, n_connected, n_connected_old;
 
       natom = carts.get_natom();
       coord_2d = carts.get_coord_2d();
@@ -386,10 +497,48 @@ internals :: internals(cartesians& carts, int user_intcos)
         bonds[b][a] = 0;
       }
 
-      /* make sure diatomics are always bonded */
-      if ( (natom == 2) && (!bonds[0][1]) ) {
-        bonds[0][1] = bonds[1][0] = 1;
-      }
+      // if we are taking a geometry step or displacing along internal coordinates, then
+      // check to make sure that all atoms are bonded
+      if (optinfo.mode == MODE_OPT_STEP || optinfo.mode == MODE_DISP_IRREP ||
+          optinfo.mode == MODE_DISP_LOAD) {
+        if (cnt) {
+        int *atoms_connected_to_first = new int[natom];
+        for (i=0;i<natom;++i)
+          atoms_connected_to_first[i] = 0;
+        n_connected = 1;
+        atoms_connected_to_first[0] = 1;
+      
+        do {
+          n_connected_old = n_connected;
+          for (i=0;i<natom;++i) {
+            if (atoms_connected_to_first[i]) {
+              for (j=0;j<natom;++j) {
+                if (!atoms_connected_to_first[j] && bonds[i][j]) { // a new connection
+                  ++n_connected;
+                  atoms_connected_to_first[j] = 1;
+                }
+              }
+            }
+          }
+        }
+        while (n_connected > n_connected_old);
+  
+        n_connected = 0;
+        for (i=0;i<natom;++i)
+          if (atoms_connected_to_first[i]) ++n_connected;
+        
+        if (n_connected != natom) {
+          fprintf(outfile,"\n\t** ERROR - Not all atoms are connected by bonds.\n");
+          fprintf(outfile,"\tYou will need to specify internal coordinates manually.\n");
+          fprintf(outfile,"\n\tAtoms connected to the 1st atom:");
+          for (i=1;i<natom;++i)
+            if (atoms_connected_to_first[i]) fprintf(outfile," %d",i+1);
+          fprintf(outfile,"\n");
+          abort();
+        }
+        delete [] atoms_connected_to_first;
+        }
+      } // end - check to make sure that all atoms are bonded
 
       /* determine stretch internal coordinates */
       id_count = 0; // index the id numbers of internals
@@ -646,12 +795,14 @@ internals :: internals(cartesians& carts, int user_intcos)
         print(fp_intco,0); 
         fclose(fp_intco);
       }
+      
+      free_int_matrix(bonds);
     } // end generate internals loop
     } // end count, creation loop
 
-    num = stre.get_num() + bend.get_num() + tors.get_num() +
-      out.get_num() + lin_bend.get_num();
-    if (num == 0) {
+    int tnum = stre.get_num() + bend.get_num() + tors.get_num() +
+      out.get_num() + lin_bend.get_num() + frag.get_num();
+    if (tnum == 0) {
       fprintf(outfile,"Error: No simple internals were generated and read.  You may ");
       fprintf(outfile,"have to increase the value of the scale_connectivity keyword.");
       exit(2);
@@ -679,6 +830,7 @@ void internals :: print(FILE *fp_out, int print_flag) {
       tors.print(fp_out, print_flag);
       out.print(fp_out, print_flag);
       lin_bend.print(fp_out, print_flag);
+      frag.print(fp_out, print_flag, 1); /* last specifies whether to print weights */
       if (print_flag == 0) fprintf(fp_out, ")\n");
   return;
 }
@@ -696,6 +848,7 @@ void internals :: compute_internals(int natom, double *geom) {
   tors.compute(natom, geom);
   out.compute(natom, geom);
   lin_bend.compute(natom, geom);
+  frag.compute(geom);
   return;
 }
 
@@ -712,6 +865,7 @@ void internals :: compute_s(int natom, double *geom) {
   tors.compute_s(natom, geom);
   out.compute_s(natom, geom);
   lin_bend.compute_s(natom, geom);
+  frag.compute_s(natom, geom);
   return;
 }
 
@@ -728,6 +882,7 @@ void internals :: print_s() {
   tors.print_s();
   out.print_s();
   lin_bend.print_s();
+  frag.print_s();
   return;
 }
 
@@ -747,3 +902,6 @@ int is_unique(int a, int b, int c, int d, int *aa, int *bb, int *cc, int *dd) {
   // fprintf(outfile,"unique returning %d\n",unique);
   return unique;
 }
+
+}} /* namespace psi::optking */
+
