@@ -1,23 +1,19 @@
-// NEW_GEOM performs the back-transformation to cartesian coordinates.
-// It computes a new cartesian geometry from an old cartesian geometry
-// and a set of internal coordinate displacements
-// it returns 1 if a new cartesian geometry was successfully determined
+/*! \file
+    \ingroup OPTKING
+    \brief NEW_GEOM performs the back-transformation to cartesian coordinates.
+It computes a new cartesian geometry from an old cartesian geometry
+and a set of internal coordinate displacements
+it returns 1 if a new cartesian geometry was successfully determined
+*/
 
-#if HAVE_CMATH
-# include <cmath>
-#else
-# include <math.h>
-#endif
-
-extern "C" {
-#include <stdio.h>
+#include <cmath>
+#include <cstdio>
 #include <libchkpt/chkpt.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <libciomr/libciomr.h>
 #include <physconst.h>
 #include <psifiles.h>
-}
 
 #define EXTERN
 #include "opt.h"
@@ -26,10 +22,11 @@ extern "C" {
 #include "internals.h"
 #include "salc.h"
 
+namespace psi { namespace optking {
+
 double *compute_q(internals &simples, salc_set &all_salcs);
 double **compute_B(internals &simples, salc_set &all_salcs);
 double **compute_G(double **B, int num_intcos, cartesians &carts);
-void symmetrize_geom(double *x);
 
 int new_geom(cartesians &carts, internals &simples, salc_set &all_salcs,
     double *dq, int print_flag, int restart_geom_file,
@@ -220,21 +217,21 @@ int new_geom(cartesians &carts, internals &simples, salc_set &all_salcs,
     symmetrize_geom(x);
 
   //  carts.set_coord(x); can't change calling geometry - may be reused
-  no_fx = new double [3*optinfo.nallatom];
+//  no_fx = new double [3*optinfo.nallatom];
 
-  for (i=0;i<3*optinfo.nallatom;++i) no_fx[i] = 0.0;
-  for (i=0;i<natom;++i) {
+//  for (i=0;i<3*optinfo.nallatom;++i) no_fx[i] = 0.0;
+//  for (i=0;i<natom;++i) {
   // make fcoord for writing to chkpt - not sure why I have to do this
   // but wt_geom doesn't seem to work if dummy atoms are present
-    no_fx[3*optinfo.to_dummy[i]+0] = x[i*3+0];
-    no_fx[3*optinfo.to_dummy[i]+1] = x[i*3+1];
-    no_fx[3*optinfo.to_dummy[i]+2] = x[i*3+2];
-  }
+//    no_fx[3*optinfo.to_dummy[i]+0] = x[i*3+0];
+//    no_fx[3*optinfo.to_dummy[i]+1] = x[i*3+1];
+//    no_fx[3*optinfo.to_dummy[i]+2] = x[i*3+2];
+//  }
 
   // cart_temp is used to return results to output.dat and chkpt
   cartesians cart_temp;
   cart_temp.set_coord(x);
-  cart_temp.set_fcoord(no_fx);
+//  cart_temp.set_fcoord(no_fx);
 
   fprintf(outfile,"\n%s\n",disp_label);
   cart_temp.print(1,outfile,0,disp_label,0);
@@ -271,48 +268,4 @@ int new_geom(cartesians &carts, internals &simples, salc_set &all_salcs,
   return 1;
 }
 
-
-void symmetrize_geom(double *x) {
-  int ua, op, xyz, num_uniques, i;
-  int atom1, atom2, *ua2a, **ict, diag_ind, natom;
-  double **cartrep, *x_temp;
-  int stab_order;
-
-  chkpt_init(PSIO_OPEN_OLD);
-  num_uniques = chkpt_rd_num_unique_atom();
-  ua2a = chkpt_rd_ua2a();
-  nirreps = chkpt_rd_nirreps();
-  ict = chkpt_rd_ict();
-  cartrep = chkpt_rd_cartrep();
-  natom = chkpt_rd_natom();
-  chkpt_close();
-
-  x_temp = init_array(natom*3);
-
-  for(ua=0; ua<num_uniques; ua++) {
-    atom1 = ua2a[ua];
-    stab_order = 0;
-    for(op=0; op < nirreps; op++) {
-      atom2 = ict[op][atom1] - 1;
-      if (atom1 == atom2)
-        stab_order++;
-    }
-    for(op=0; op < nirreps; op++) {
-      atom2 = ict[op][atom1] - 1;
-      for(xyz=0; xyz<3; xyz++) {
-        diag_ind = xyz*3 + xyz;
-        x_temp[3*atom2+xyz] += cartrep[op][diag_ind] * x[3*atom1+xyz] / stab_order;
-      }
-    }
-  }
-
-  for (i=0;i<3*natom;++i)
-    x[i] = x_temp[i];
-
-  free(x_temp);
-  free(ua2a);
-  free_int_matrix(ict, nirreps);
-  free_block(cartrep);
-  return;
-}
-
+}} /* namespace psi::optking */
