@@ -1,6 +1,7 @@
-/*** OPT.CC Rollin King, begun 1999 ***/
-
-/*
+/*! \file
+    \ingroup OPTKING
+    \brief main optking function
+    OPT.CC Rollin King, begun 1999 
 command-line      internal specifier   what it does
 --opt_step         MODE_OPT_STEP        take an ordinary geometry optimization step
 --disp_nosymm      MODE_DISP_NOSYMM     displaces along all internals, assumes no sym
@@ -17,6 +18,7 @@ command-line      internal specifier   what it does
 --reset_prefix     MODE_RESET_PREFIX    only reset the prefix of PSIF
 --disp_num_plus    MODE_DISP_NUM_PLUS   only increment the current displacement number PSIF
 --delete_binaries  MODE_DELETE_BINARIES just delete binary files
+--test_B           MODE_TEST_BMAT       build B matrix and test numerically
 --points           optinfo.points       save the energy in chkpt to PSIF list
 --disp_num         optinfo.disp_num     displacement index (by default read from PSIF)
 --irrep            optinfo.irrep       the irrep (1,2,...) being displaced or computed
@@ -29,26 +31,19 @@ command-line      internal specifier   what it does
 --grad_dat         optinfo.grad_dat   read gradients from file11.dat 
 */
 
-#if HAVE_CMATH
-# include <cmath>
-#else
-# include <math.h>
-#endif
-
-extern "C" {
-  #include <stdio.h>
-  #include <libchkpt/chkpt.h>
-  #include <stdlib.h>
-  #include <string.h>
-  #include <ctype.h>
-  #include <libciomr/libciomr.h>
-  #include <libipv1/ip_lib.h>
-  #include <physconst.h>
-  #include <libpsio/psio.h>
-  #include <libqt/qt.h>	  
-  #include <psifiles.h>
-  #include <ccfiles.h>
-}
+#include <cmath>
+#include <cstdio>
+#include <libchkpt/chkpt.h>
+#include <cstdlib>
+#include <cstring>
+#include <cctype>
+#include <libciomr/libciomr.h>
+#include <libipv1/ip_lib.h>
+#include <physconst.h>
+#include <libpsio/psio.h>
+#include <libqt/qt.h>	  
+#include <psifiles.h>
+#include <ccfiles.h>
 
 #include "opt.h"
 #include "cartesians.h"
@@ -56,11 +51,13 @@ extern "C" {
 #include "salc.h"
 #include "bond_lengths.h"
 
+namespace psi { namespace optking {
+
 void intro(int argc, char **argv);
 void free_info(int nsimples);
 int *count_internals(cartesians &cart_geom, int intco_given);
-extern "C" void zmat_to_intco(void);
-extern "C" void get_optinfo();
+extern void zmat_to_intco(void);
+extern void get_optinfo();
 extern void get_syminfo(internals &simples);
 extern void delocalize(internals &simples, cartesians &carts);
 extern void disp_user(cartesians &carts, internals &simples, 
@@ -79,15 +76,23 @@ extern void grad_energy(cartesians &carts, internals &simples,
 extern void grad_save(cartesians &carts);
 extern void energy_save(cartesians &carts);
 extern int opt_step(cartesians &carts, internals &simples, salc_set &symm_salcs);
+extern int opt_step_cart(cartesians &carts, internals &simples, salc_set &symm_salcs);
 extern int *read_constraints(internals &simples);
 
 extern int disp_freq_grad_cart(cartesians &carts);
 extern void freq_grad_cart(cartesians &carts);
 extern int disp_freq_energy_cart(cartesians &carts);
 extern void freq_energy_cart(cartesians &carts);
+int test_B(cartesians &carts, internals &simples, salc_set &symm);
 
 void chkpt_restart(char *new_prefix);
 
+}} // namespace psi::optking
+
+extern "C" { const char *gprgid() { const char *prgid = "OPTKING"; return(prgid); } }
+
+using namespace psi::optking;
+
 int main(int argc, char **argv) {
 
     int i,j,a,b,dim,count,dim_carts,user_intcos, *constraints,xyz;
@@ -99,7 +104,7 @@ int main(int argc, char **argv) {
     optinfo.mode = MODE_OPT_STEP;
     optinfo.disp_num = 0;
     optinfo.points = 3;
-    optinfo.points_freq = 3; // always 3 for now
+    optinfo.points_freq_grad_ints = 3; // always 3 for now
     optinfo.energy_dat = 0;
     optinfo.grad_dat = 0;
     for (i=1; i<argc; ++i) {
@@ -179,6 +184,10 @@ int main(int argc, char **argv) {
         optinfo.mode = MODE_DELETE_BINARIES;
         parsed++;
       }
+      else if (!strcmp(argv[i],"--test_B")) {
+        optinfo.mode = MODE_TEST_BMAT;
+        parsed++;
+      }
       else if (!strcmp(argv[i],"--points")) {
         sscanf(argv[++i], "%d", &optinfo.points);
         parsed+=2;
@@ -201,12 +210,13 @@ int main(int argc, char **argv) {
         parsed++;
       }
       else {
-        printf("command line argument not understood.\n");
-        exit(1);
+        //printf("command line argument not understood.\n");
+        //exit(1);
+		break;
       }
     }
 
-    psi_start(argc-parsed,argv+parsed,0);
+    psi_start(&infile,&outfile,&psi_file_prefix,argc-parsed,argv+parsed,0);
     /* init_in_out() sets the value of "infile", so we need to save it */
     fp_input = infile;
     
@@ -218,20 +228,18 @@ int main(int argc, char **argv) {
     optinfo.simples_present = 0;
     optinfo.salcs_present = 0;
     ffile_noexit(&fp_intco, "intco.dat", 2);
-    if (fp_intco != NULL) {
+    if (fp_intco != NULL)
       ip_append(fp_intco, outfile) ;
-      if ( ip_exist(":INTCO",0) ) {
-        ip_cwk_add(":INTCO");
-        optinfo.simples_present = 1;
-      }
-      if ( ip_exist("SYMM",0) || ip_exist("ASYMM",0) )
-        optinfo.salcs_present = 1;
-      fclose(fp_intco);
+    if ( ip_exist(":INTCO",0) ) {
+      ip_cwk_add(":INTCO");
+      optinfo.simples_present = 1;
     }
-    //printf("simples_present already? %d\n",optinfo.simples_present);
-    //printf("salcs_present already? %d\n",optinfo.salcs_present);
+    if ( ip_exist("SYMM",0) || ip_exist("ASYMM",0) )
+      optinfo.salcs_present = 1;
+    if (fp_intco != NULL)
+      fclose(fp_intco);
 
-    psio_init();
+    psio_init(); psio_ipv1_config();
     get_optinfo();
 
     // generate simples from zmat
@@ -256,7 +264,7 @@ int main(int argc, char **argv) {
            && (optinfo.mode != MODE_RESET_PREFIX) && (optinfo.mode != MODE_DISP_NUM_PLUS)
            && (optinfo.mode != MODE_DELETE_BINARIES) ) {
       fprintf(outfile,
-      "\nCartesian geometry and possibly gradient in a.u. with masses\n");
+      "\nCartesian geometry in a.u. with masses\n");
       carts.print(2,outfile,0,disp_label,0);
     }
     delete [] disp_label;
@@ -273,7 +281,7 @@ int main(int argc, char **argv) {
     coord = carts.get_coord();
     simples.compute_internals(carts.get_natom(), coord);
     simples.compute_s(carts.get_natom(), coord);
-    // simples.print_s();
+//simples.print_s();
     free(coord);
     if ( (optinfo.mode != MODE_DISP_LOAD) && (optinfo.mode != MODE_LOAD_REF)
       && (optinfo.mode != MODE_RESET_PREFIX) && (optinfo.mode != MODE_DISP_NUM_PLUS)
@@ -292,7 +300,6 @@ int main(int argc, char **argv) {
     if (!(optinfo.salcs_present)) {
       if (optinfo.delocalize) {
         fprintf(outfile,"\nForming delocalized internal coordinates.\n");
-        // delocalize(carts.get_natom(),simples);
         delocalize(simples, carts);
       }
       else {
@@ -347,10 +354,18 @@ int main(int argc, char **argv) {
       salc_set symm_salcs("SYMM");
       if (!optinfo.redundant)
         symm_salcs.print();
-      a = opt_step(carts, simples, symm_salcs);
+      if (optinfo.test_B) {
+        test_B(carts,simples,symm_salcs);
+        coord = carts.get_coord(); // restore internals to undisplaced state
+        simples.compute_internals(carts.get_natom(), coord);
+        simples.compute_s(carts.get_natom(), coord);
+      }
+      if (optinfo.cartesian)
+        a = opt_step_cart(carts, simples, symm_salcs);
+      else
+        a = opt_step(carts, simples, symm_salcs);
       free_info(simples.get_num());
       exit_io();
-      // fprintf(stderr,"Optking returning value %d\n", a);
       return a;
     }
 
@@ -518,6 +533,15 @@ int main(int argc, char **argv) {
       return(0);
     }
 
+    if (optinfo.mode == MODE_TEST_BMAT) {
+      fprintf(outfile," \n ** Testing B matrix **\n");
+      salc_set symm_salcs("SYMM");
+      test_B(carts,simples,symm_salcs);
+      free_info(simples.get_num());
+      exit_io();
+      return (0);
+    }
+
     if (optinfo.mode == MODE_RESET_PREFIX) {
       /* delete CC temporary files */
       if((strcmp(optinfo.wfn, "MP2")==0)       || (strcmp(optinfo.wfn, "CCSD")==0)  ||
@@ -587,7 +611,9 @@ int main(int argc, char **argv) {
       close_PSIF();
     }
     return(0);
-  }
+}
+
+namespace psi { namespace optking {
 
 /***  INTRO   prints into ***/
 void intro(int argc, char **argv) {
@@ -614,29 +640,28 @@ void free_info(int nsimples) {
 
  // free syminfo
   free(syminfo.symmetry);
+  free_int_matrix(syminfo.ct);
+  free_int_matrix(syminfo.ict);
+  free_int_matrix(syminfo.fict);
   for (i=0; i<syminfo.nirreps; ++i) {
-    free(syminfo.ct[i]);
-    free(syminfo.ict[i]);
-    free(syminfo.fict[i]);
     free(syminfo.irrep_lbls[i]);
     free(syminfo.clean_irrep_lbls[i]);
   }
-  free(syminfo.ct);
-  free(syminfo.ict);
-  free(syminfo.fict);
   free(syminfo.irrep_lbls);
   free(syminfo.clean_irrep_lbls);
-
-  for (i=0; i<nsimples; ++i) {
-    free(syminfo.ict_ops[i]);
-    free(syminfo.ict_ops_sign[i]);
-  }
-  free(syminfo.ict_ops);
-  free(syminfo.ict_ops_sign);
+  
+  free_int_matrix(syminfo.ict_ops);
+  free_int_matrix(syminfo.ict_ops_sign);
 
   // free optinfo
   free(optinfo.to_dummy);
   free(optinfo.to_nodummy);
+  if (optinfo.nfragment > 1) {
+    free(optinfo.natom_per_fragment);
+    free(optinfo.nallatom_per_fragment);
+    free(optinfo.nref_per_fragment);
+    free(optinfo.fragment_coeff);
+  }
   return;
 }
 
@@ -705,3 +730,5 @@ void chkpt_restart(char *new_prefix) {
   chkpt_close();
   return;
 }
+
+}} /* namespace psi::optking */
