@@ -1,19 +1,15 @@
-/*** PRINT_ZMAT() printout z-matrix ***/ 
+/*! \file
+    \ingroup OPTKING
+    \brief PRINT_ZMAT() printout z-matrix
+*/
 
-#if HAVE_CMATH
-# include <cmath>
-#else
-# include <math.h>
-#endif
-
-extern "C" {
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cmath>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 #include <physconst.h>
 #include <libciomr/libciomr.h>
 #include <libchkpt/chkpt.h>
-}
 
 #define EXTERN
 #include "opt.h"
@@ -21,6 +17,8 @@ extern "C" {
 #include "cartesians.h"
 #include "internals.h"
 
+namespace psi { namespace optking {
+
 void compute_zmat(cartesians &carts, int *unique_zvars);
 void print_zmat(FILE *outfile, int *unique_zvars);
 
@@ -92,19 +90,23 @@ void compute_zmat(cartesians &carts, int *unique_zvars) {
   }
 
   int *nints;
-  nints = (int *) malloc(5*sizeof(int));
-  nints[0] = nallatom-1;
-  nints[1] = nallatom-2;
-  nints[2] = nallatom-3;
-  nints[3] = 0;
-  nints[4] = 0;
+  nints = (int *) malloc(6*sizeof(int));
+  nints[0] = nallatom-1; /* stre */
+  nints[1] = nallatom-2; /* bend */
+  nints[2] = nallatom-3; /* tors */
+  nints[3] = 0; /* oop */
+  nints[4] = 0; /* lin_bend */
+  nints[5] = 0; /* fragment */
+  for (i=0; i<6; ++i)
+    if (nints[i] < 0) nints[i] = 0;
   internals zints(nints);
   /* compute the value of the unique variables */
-  zints.stre.set_num(nallatom-1);
-  zints.bend.set_num(nallatom-2);
-  zints.tors.set_num(nallatom-3);
+  zints.stre.set_num(nints[0]);
+  zints.bend.set_num(nints[1]);
+  zints.tors.set_num(nints[2]);
   zints.out.set_num(0);
   zints.lin_bend.set_num(0);
+  zints.frag.set_num(0);
 
   cnt = 0;
   for (i=0;i<nallatom;++i) {
@@ -128,7 +130,7 @@ void compute_zmat(cartesians &carts, int *unique_zvars) {
     }
   }
   // compute value of the zmatrix coordinates
-  opt_fgeom = carts.get_coord();
+  opt_fgeom = carts.get_fcoord();
   zints.compute_internals(nallatom, opt_fgeom);
 
   // insert computed values into zmatrix object
@@ -203,26 +205,34 @@ void print_zmat(FILE *outfile, int *unique_zvars) {
     fprintf(outfile,")\n");
   }
   fprintf(outfile,"  )\n");
-  cnt = -1;
-  fprintf(outfile,"  zvars = ( \n");
-  for (i=0; i<nallatom; ++i) {
-    if (i > 0) {
-      if (unique_zvars[++cnt])
-        fprintf(outfile,"    ( %s %10.5lf )\n",
-            zmat[i].bond_label, zmat[i].bond_val);
-    }
-    if (i > 1) {
-      if (unique_zvars[++cnt])
-        fprintf(outfile,"    ( %s %10.5lf )\n",
-            zmat[i].angle_label, zmat[i].angle_val);
-    }
-    if (i > 2) {
-      if (unique_zvars[++cnt])
-        fprintf(outfile,"    ( %s %10.5lf )\n",
-            zmat[i].tors_label, zmat[i].tors_val);
+  int cnt_vars = 0;
+  for (i=0;i<MAX_ZVARS;++i)
+    if (unique_zvars[i]) ++cnt_vars;
+
+  if (cnt_vars != 0) {
+    cnt = -1;
+    fprintf(outfile,"  zvars = ( \n");
+    for (i=0; i<nallatom; ++i) {
+      if (i > 0) {
+        if (unique_zvars[++cnt])
+          fprintf(outfile,"    ( %s %10.5lf )\n",
+              zmat[i].bond_label, zmat[i].bond_val);
+      }
+      if (i > 1) {
+        if (unique_zvars[++cnt])
+          fprintf(outfile,"    ( %s %10.5lf )\n",
+              zmat[i].angle_label, zmat[i].angle_val);
+      }
+      if (i > 2) {
+        if (unique_zvars[++cnt])
+          fprintf(outfile,"    ( %s %10.5lf )\n",
+              zmat[i].tors_label, zmat[i].tors_val);
+      }
     }
+    fprintf(outfile,"  )\n");
   }
-  fprintf(outfile,"  )\n");
   return;
 }
 
+}} /* namespace psi::optking */
+
