@@ -1,3 +1,10 @@
+/*! \file
+    \ingroup RESPONSE
+    \brief Enter brief description of file here 
+*/
+
+namespace psi { namespace response {
+
 struct Params {
   int print;             /* Output level control */
   long int memory;       /* Memory available (in bytes) */
@@ -5,3 +12,5 @@ struct Params {
   int ref;               /* reference determinant (0=RHF, 1=ROHF, 2=UHF) */
   double omega;          /* energy of applied field (a.u) for dynamic polarizabilities */
 };
+
+}} // namespace psi::response
