@@ -1,3 +1,10 @@
+/*! \file
+    \ingroup STABLE
+    \brief Enter brief description of file here 
+*/
+
+namespace psi { namespace stable {
+
 struct Params {
   int print_lvl;         /* Output level control */
   long int memory;       /* Memory available (in bytes) */
@@ -8,3 +15,5 @@ struct Params {
   int rotation_method;   /* 0 = by angles, 1 = by antisymmetric matrix */
   double scale;          /* scale factor for orbital rotation step */
 };
+
+}} // namespace psi::stable
