@@ -1,6 +1,10 @@
+/*! \file
+    \ingroup STABLE
+    \brief Enter brief description of file here 
+*/
 #include <ccfiles.h>
-#include "MOInfo.h"
-#include "Params.h"
+
+namespace psi { namespace stable {
 
 /* Global variables */
 #ifdef EXTERN
@@ -10,11 +14,14 @@
 #define EXTERN
 #endif
 
+extern "C" {
 EXTERN FILE *infile, *outfile;
 EXTERN char *psi_file_prefix;
+}
 EXTERN int *ioff;
 EXTERN struct MOInfo moinfo;
 EXTERN struct Params params;
 
 #define MIN0(a,b) (((a)<(b)) ? (a) : (b))
 
+}} // namespace psi::stable
