@@ -1,5 +1,14 @@
+/*! \file
+    \ingroup TRANSQT
+    \brief Enter brief description of file here 
+*/
 /* Struct for input parameters */
 
+#ifndef _psi3_bin_transqt_Params_h_
+#define _psi3_bin_transqt_Params_h_
+
+namespace psi { namespace transqt {
+
 struct Params {
   int runmode;                  /* which mode we are running in, defined
                                    in globals.h                           */
@@ -65,10 +74,13 @@ struct Params {
   int qrhf;                     /* boolean for QRHF reference             */
   int ivo;                      /* boolean for test IVO's                 */
   int semicanonical;            /* boolean for Semicanonical orbitals     */
+                                /* now semicanonical is used as an integer:
+                                  ==1 for semicanonical, 2 for z-averaged */
 
-  char *aobasis;                /* string for AO-Basis CC algorithms     */
+  char *aobasis;                /* string for AO-Basis CC algorithms      */
 
   int pitzer;                   /* boolean to override all MO reordering  */
+  int psimrcc;                  /* boolean for psimrcc settings           */
 };
 
 /* Note that the current version does a reordering of orbital indices.
@@ -77,3 +89,6 @@ struct Params {
  * currently output only to 'mfile' after reordering, and not to 
  * 'sorted_tei_file'
  */
+
+}} // end namespace psi::transqt
+#endif // header guard
