@@ -1,5 +1,11 @@
-#ifndef YOSHIMINE_H
-#define YOSHIMINE_H
+/*! \file
+    \ingroup TRANSQT
+    \brief Enter brief description of file here 
+*/
+#ifndef _psi3_bin_transqt_yoshimine_h_
+#define _psi3_bin_transqt_yoshimine_h_
+
+namespace psi { namespace transqt {
 
 /*
 ** YOSHIMINE.H 
@@ -67,7 +73,7 @@ YEXTERN void yosh_rdtwo_uhf(struct yoshimine *YBuff, int itapERI, int del_tei_fi
 YEXTERN void yosh_rdtwo_backtr(struct yoshimine *YBuff, int tei_file, 
       int *ioff, int symmetrize, int add_ref_pt, int del_tei_file, int prtflg, 
       FILE *outfile);
-YEXTERN void yosh_rdtwo_backtr_uhf(char *spin, struct yoshimine *YBuff, int tei_file, 
+YEXTERN void yosh_rdtwo_backtr_uhf(const char *spin, struct yoshimine *YBuff, int tei_file, 
       int *ioff, int swap_bk, int symm_pq, int del_tei_file, int prtflg, FILE *outfile);
 YEXTERN void flush_bucket(struct bucket *bptr, int lastbuf);
 YEXTERN void yosh_sort(struct yoshimine *YBuff, int out_tape, int keep_bins,
@@ -93,4 +99,10 @@ YEXTERN void add_2pdm_ref_pt(struct yoshimine *YBuff,int *ioff,int prtflg,
 YEXTERN void yosh_buff_put_val(struct yoshimine *YBuff, int *ioff, int pq,
                        int p, int q, int r, int s, double value, int prtflg,
                        FILE *outfile);
-#endif /* end YOSHIMINE_H */
+YEXTERN void yosh_wrt_arr_mp2r12a(struct yoshimine *YBuff, int p, int q, int pq,
+                          int pqsym, double **arr, int rsym, int *firstr,
+                          int *lastr, int *firsts, int *lasts, int sortby_rs,
+                          int *occ, int *ioff3,
+                          int printflag, FILE *outfile);
+}} // end namespace psi::transqt
+#endif // header guard
