@@ -1,3 +1,11 @@
+/*! \file
+    \ingroup TRANSQT2
+    \brief Enter brief description of file here 
+*/
+
+namespace psi {
+  namespace transqt2 {
+
 struct Params {
   char *wfn;
   int ref;
@@ -12,4 +20,8 @@ struct Params {
   long int memory;    /* Memory available (in bytes) */
   int semicanonical;  /* Boolean for semicanonical orbitals */
   int delete_tei;     /* Boolean for the TEI integral file */
+  int backtr;         /* Boolean for back-transforms (not yet implemented) */
 };
+
+  } // namespace transqt2
+} // namespace psi
