@@ -1,7 +1,14 @@
+/*! \file
+    \ingroup BASIS
+    \brief Enter brief description of file here 
+*/
+
+/*! \defgroup BASIS libbasis: The Basis Set Library */
+
 #include <stdexcept>
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cmath>
 extern "C" {
 #include <libciomr/libciomr.h>
 #include <libchkpt/chkpt.h>
@@ -10,6 +17,8 @@ extern "C" {
 #include "basisset.h"
 //#include "shell_pairs.h"
 
+using namespace psi;
+
 BasisSet::BasisSet(int chkptfile)
 {
   num_shells_ = chkpt_rd_nshell();
@@ -17,7 +26,7 @@ BasisSet::BasisSet(int chkptfile)
   num_ao_ = chkpt_rd_nao();
   // Psi 3 only allows either all Cartesians or all Spherical harmonics only
   num_bf_ = chkpt_rd_nso();
-  puream_ = (num_bf_ != num_ao_);
+  puream_ = chkpt_rd_puream();
   max_am_ = chkpt_rd_max_am();
 
   shells_ = new GaussianShell*[num_shells_];
@@ -55,10 +64,10 @@ BasisSet::~BasisSet()
   //dealloc_pairs();
   for(int s=0; s<num_shells_; s++)
     shells_[s]->~GaussianShell();
-  free(shells_);
-  delete[] shell_center_;
-  delete[] shell_fao_;
-  delete[] shell_fbf_;
+  delete[] shells_;
+  free(shell_center_);
+  free(shell_fao_);
+  free(shell_fbf_);
   free_block(coords_);
 }
 
@@ -116,9 +125,9 @@ void BasisSet::init_shells()
 
    free_block(ccoeffs);
    free(exponents);
-   delete[] shell_am;
-   delete[] shell_num_prims;
-   delete[] shell_fprim;
+   free(shell_am);
+   free(shell_num_prims);
+   free(shell_fprim);
 }
 
 void BasisSet::check_shell_index(int si) const {
