@@ -1,3 +1,7 @@
+/*! \file
+    \ingroup BASIS
+    \brief Enter brief description of file here 
+*/
 
 extern "C" {
 #include <libciomr/libciomr.h>
@@ -6,12 +10,11 @@ extern "C" {
 #include <stdexcept>
 #include "combinate.h"
 
+using namespace psi;
+
 StatCombData::StatCombData(int imax) :
   imax_(imax)
 {
-  if (imax < 1)
-    throw std::runtime_error("ERROR: StatCombData::StatCombData -- argument out of range");
-
   Fact_ = new PSI_FLOAT[imax+1];
   Fact_[0] = 1.0;
   for(int i=1; i<=imax; i++)
@@ -33,5 +36,5 @@ StatCombData::~StatCombData()
 {
   delete[] Fact_;
   delete[] Fact2_;
-  delete[] BinomC_;
+  free_block(BinomC_);
 }
