@@ -1,3 +1,7 @@
+/*! \file
+    \ingroup BASIS
+    \brief Enter brief description of file here 
+*/
 
 // I know "combinate" is not a word
 
@@ -7,9 +11,10 @@
 #include <stdexcept>
 #include <psitypes.h>
 
+namespace psi {
+
 /** Class StatCombData contains static data of combinatorial type -
     factorials, binomial coefficients, etc. */
-
 class StatCombData {
 
   int imax_;
@@ -42,4 +47,6 @@ class StatCombData {
   PSI_FLOAT binomc(int n, int m) const { check_index(n); check_index(m); return BinomC_[n][m]; };
 };
 
+} // end of namespace psi
+
 #endif
