@@ -1,9 +1,15 @@
+/*! \file
+    \ingroup BASIS
+    \brief Enter brief description of file here 
+*/
 
 #ifndef _psi_src_lib_libbasis_osrecur_h_
 #define _psi_src_lib_libbasis_osrecur_h_
 
 #include <psitypes.h>
 
+namespace psi {
+
 class OI_OSRecursor {
 
   int maxam1_;
@@ -28,4 +34,6 @@ class OI_OSRecursor {
   void compute(PSI_FLOAT PA[3], PSI_FLOAT PB[3], PSI_FLOAT gamma, int am1, int am2);
 };
 
+} // end of namespace psi
+
 #endif
