@@ -1,3 +1,7 @@
+/*! \file
+    \ingroup BASIS
+    \brief Enter brief description of file here 
+*/
 
 #ifndef _psi_src_lib_libbasis_overlap_h_
 #define _psi_src_lib_libbasis_overlap_h_
@@ -8,6 +12,8 @@
 #include "osrecur.h"
 #include "gnorm.h"
 
+namespace psi {
+
 class OverlapEngine {
 
   const BasisSet* bs1_;
@@ -30,4 +36,6 @@ class OverlapEngine {
   PSI_FLOAT** compute_full_matrix();
 };
 
+} // end of namespace psi
+
 #endif
