@@ -1,9 +1,15 @@
+/*! \file
+    \ingroup BASIS
+    \brief Enter brief description of file here 
+*/
 
 #ifndef _psi_src_lib_libbasis_shell_h_
 #define _psi_src_lib_libbasis_shell_h_
 
 #include <psitypes.h>
 
+namespace psi {
+
 class BasisSet;
 
 class GaussianShell {
@@ -67,4 +73,6 @@ class GaussianShell {
 
 };
 
+} // end of namespace psi
+
 #endif
