@@ -4,44 +4,23 @@
 
 #include <libpsio/psio.h>
 #include <chkpt_params.h>
+#include <libchkpt/config.h>
 
-#define MAX_ELEMNAME 13
-
-#define CHKPT_PREFIX_LEN 32
-extern char chkpt_prefix[CHKPT_PREFIX_LEN];
-
-/*--- Z-matrix entry type ---*/
-struct z_entry {
-  int bond_atom;            /* first reference atom (bond) */
-  int angle_atom;           /* second reference atom (angle) */
-  int tors_atom;            /* third reference atom (torsion) */
-  int bond_opt;             /* flags indicating to optimize values */
-  int angle_opt; 
-  int tors_opt; 
-  double bond_val;          /* coordinate values */
-  double angle_val; 
-  double tors_val; 
-  char bond_label[20];      /* variable labels, if any */
-  char angle_label[20]; 
-  char tors_label[20]; 
-};
-
-/*--- Types of reference determinants ---*/
-typedef enum {ref_rhf = 0, ref_uhf = 1, ref_rohf = 2, ref_tcscf = 3,
-	      ref_rks = 4, ref_uks = 5} reftype;
-
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 int chkpt_init(int status);
 int chkpt_close(void);
 
 char *chkpt_rd_prefix(void);
-void chkpt_wt_prefix(char *prefix);
-void chkpt_set_prefix(char *prefix);
+void chkpt_wt_prefix(const char *prefix);
+void chkpt_set_prefix(const char *prefix);
 void chkpt_commit_prefix(void);
 void chkpt_reset_prefix(void);
 char *chkpt_get_prefix(void);
 
-char *chkpt_build_keyword(char *);
+char *chkpt_build_keyword(const char *);
 
 int chkpt_rd_ncalcs(void);
 
@@ -143,7 +122,7 @@ int chkpt_rd_nallatom(void);
 void chkpt_wt_nallatom(int);
 
 char **chkpt_rd_felement(void);
-void chkpt_wt_felement(char **);
+void chkpt_wt_felement(char ** const);
 
 double **chkpt_rd_usotao(void);
 void chkpt_wt_usotao(double **);
@@ -196,6 +175,9 @@ void chkpt_wt_rottype(int);
 int chkpt_rd_max_am(void);
 void chkpt_wt_max_am(int);
 
+int chkpt_rd_puream(void);
+void chkpt_wt_puream(int);
+
 int chkpt_rd_nso(void);
 void chkpt_wt_nso(int);
 
@@ -252,14 +234,23 @@ void chkpt_wt_ccvecs(double **);
 double chkpt_rd_ecorr(void);
 void chkpt_wt_ecorr(double);
 
+double chkpt_rd_eccsd(void);
+void chkpt_wt_eccsd(double);
+
+double chkpt_rd_e_t(void);
+void chkpt_wt_e_t(double);
+
+double chkpt_rd_emp2(void);
+void chkpt_wt_emp2(double);
+
 double chkpt_rd_eref(void);
 void chkpt_wt_eref(double);
 
 double chkpt_rd_efzc(void);
 void chkpt_wt_efzc(double);
 
-double chkpt_rd_e_labeled(char *);
-void chkpt_wt_e_labeled(char *, double);
+double chkpt_rd_e_labeled(const char *);
+void chkpt_wt_e_labeled(const char *, double);
 
 int chkpt_rd_disp(void);
 void chkpt_wt_disp(int);
@@ -279,9 +270,36 @@ void chkpt_wt_cdsalcpi(const int*);
 double** chkpt_rd_cdsalc2cd();
 void chkpt_wt_cdsalc2cd(const double**);
 
-int chkpt_exist(char *);
+double *chkpt_rd_exps();
+void chkpt_wt_exps(double*);
+
+int chkpt_exist(const char *);
+int chkpt_exist_add_prefix(const char *);
 
 int chkpt_rd_override_occ(void);
 void chkpt_wt_override_occ(int);
 
+int *chkpt_rd_statespi(void);
+void chkpt_wt_statespi(int *);
+
+int chkpt_rd_nfragment(void);
+void chkpt_wt_nfragment(int);
+
+int *chkpt_rd_natom_per_fragment(void);
+void chkpt_wt_natom_per_fragment(int *);
+
+int *chkpt_rd_nallatom_per_fragment(void);
+void chkpt_wt_nallatom_per_fragment(int *);
+
+int *chkpt_rd_nref_per_fragment(void);
+void chkpt_wt_nref_per_fragment(int *);
+
+double ***chkpt_rd_fragment_coeff(void);
+void chkpt_wt_fragment_coeff(double ***);
+
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif
