@@ -1,7 +1,11 @@
-#ifndef DPD_H
-#define DPD_H
+/*! \file
+    \ingroup DPD
+    \brief Enter brief description of file here 
+*/
+#ifndef _psi_src_lib_libdpd_dpd_h
+#define _psi_src_lib_libdpd_dpd_h
 
-#include <stdio.h>
+#include <cstdio>
 #include <libpsio/psio.h>
 #include <libciomr/libciomr.h>
 #include <libiwl/iwl.h>
@@ -11,7 +15,11 @@
 #include <dmalloc.h>
 #endif
 
-#define T3_TIMER_ON (1)
+#ifdef __cplusplus
+extern "C" {
+#endif
+	
+#define T3_TIMER_ON (0)
 
 #define DPD_BIGNUM 2147483647 /* the four-byte signed int limit */
 /* #define ALL_BUF4_SORT_OOC */
@@ -194,7 +202,7 @@ int dpd_init(int dpd_num, int nirreps, long int memory, int cachetype,
 int dpd_close(int dpd_num);
 int dpd_set_default(int dpd_num);
 
-void dpd_error(char *caller, FILE *outfile);
+void dpd_error(const char *caller, FILE *outfile);
 
 double **dpd_block_matrix(int n, int m);
 void dpd_free_block(double **array, int n, int m);
@@ -227,14 +235,15 @@ int dpd_dot14(dpdfile2 *T, dpdbuf4 *I, dpdfile2 *Z,
 int dpd_trace42_13(dpdbuf4 *A, dpdfile2 *B, int transb, double alpha, double beta);
 
 int dpd_file2_init(dpdfile2 *File, int filenum, int irrep, int pnum,
-		   int qnum, char *label);
+		   int qnum, const char *label);
 int dpd_file2_close(dpdfile2 *File);
 int dpd_file2_mat_init(dpdfile2 *File);
 int dpd_file2_mat_close(dpdfile2 *File);
 int dpd_file2_mat_rd(dpdfile2 *File);
 int dpd_file2_mat_wrt(dpdfile2 *File);
 int dpd_file2_print(dpdfile2 *File, FILE *outfile);
-int dpd_file2_copy(dpdfile2 *InFile, int outfilenum, char *label);
+int dpd_file2_mat_print(dpdfile2 *File, FILE *outfile);
+int dpd_file2_copy(dpdfile2 *InFile, int outfilenum, const char *label);
 int dpd_file2_dirprd(dpdfile2 *FileA, dpdfile2 *FileB);
 double dpd_file2_dot(dpdfile2 *FileA, dpdfile2 *FileB);
 int dpd_file2_scm(dpdfile2 *InFile, double alpha);
@@ -247,9 +256,9 @@ int dpd_file2_axpbycz(dpdfile2 *FileA, dpdfile2 *FileB, dpdfile2 *FileC,
 
 
 int dpd_file4_init(dpdfile4 *File, int filenum, int irrep, int pqnum,
-		   int rsnum,  char *label);
+		   int rsnum,  const char *label);
 int dpd_file4_init_nocache(dpdfile4 *File, int filenum, int irrep, int pqnum,
-		   int rsnum,  char *label);
+		   int rsnum,  const char *label);
 int dpd_file4_close(dpdfile4 *File);
 int dpd_file4_mat_irrep_init(dpdfile4 *File, int irrep);
 int dpd_file4_mat_irrep_close(dpdfile4 *File, int irrep);
@@ -267,20 +276,20 @@ int dpd_file4_mat_irrep_wrt_block(dpdfile4 *File, int irrep, int start_pq,
 				 int num_pq);
 
 int dpd_buf4_init(dpdbuf4 *Buf, int inputfile, int irrep, int pqnum, int rsnum,
-		 int file_pqnum, int file_rsnum, int anti, char *label);
+		 int file_pqnum, int file_rsnum, int anti, const char *label);
 int dpd_buf4_close(dpdbuf4 *Buf);
 int dpd_buf4_mat_irrep_init(dpdbuf4 *Buf, int irrep);
 int dpd_buf4_mat_irrep_close(dpdbuf4 *Buf, int irrep);
 int dpd_buf4_mat_irrep_rd(dpdbuf4 *Buf, int irrep);
 int dpd_buf4_mat_irrep_wrt(dpdbuf4 *Buf, int irrep);
 int dpd_buf4_print(dpdbuf4 *Buf, FILE *outfile, int print_data);
-int dpd_buf4_copy(dpdbuf4 *InBuf, int outfilenum, char *label);
+int dpd_buf4_copy(dpdbuf4 *InBuf, int outfilenum, const char *label);
 int dpd_buf4_sort(dpdbuf4 *InBuf, int outfilenum, enum indices index,
-		  int pqnum, int rsnum, char *label);
+		  int pqnum, int rsnum, const char *label);
 int dpd_buf4_sort_ooc(dpdbuf4 *InBuf, int outfilenum, enum indices index,
-		      int pqnum, int rsnum, char *label);
+		      int pqnum, int rsnum, const char *label);
 int dpd_buf4_sort_axpy(dpdbuf4 *InBuf, int outfilenum, enum indices index,
-		       int pqnum, int rsnum, char *label, double alpha);
+		       int pqnum, int rsnum, const char *label, double alpha);
 int dpd_buf4_axpy(dpdbuf4 *BufX, dpdbuf4 *BufY, double alpha);
 int dpd_buf4_axpbycz(dpdbuf4 *FileA, dpdbuf4 *FileB, dpdbuf4 *FileC,
   double a, double b, double c);
@@ -288,7 +297,7 @@ int dpd_buf4_dirprd(dpdbuf4 *BufA, dpdbuf4 *BufB);
 double dpd_buf4_dot(dpdbuf4 *BufA, dpdbuf4 *BufB);
 double dpd_buf4_dot_self(dpdbuf4 *BufX);
 int dpd_buf4_scm(dpdbuf4 *InBuf, double alpha);
-int dpd_buf4_scmcopy(dpdbuf4 *InBuf, int outfilenum, char *label, 
+int dpd_buf4_scmcopy(dpdbuf4 *InBuf, int outfilenum, const char *label, 
                      double alpha);
 int dpd_buf4_symm(dpdbuf4 *Buf);
 int dpd_buf4_symm2(dpdbuf4 *Buf1, dpdbuf4 *Buf2);
@@ -325,17 +334,21 @@ void dpd_file2_cache_init(void);
 void dpd_file2_cache_close(void);
 void dpd_file2_cache_print(FILE *outfile);
 struct dpd_file2_cache_entry
- *dpd_file2_cache_scan(int filenum, int irrep, int pnum, int qnum, char *label, int dpdnum);
+ *dpd_file2_cache_scan(int filenum, int irrep, int pnum, int qnum, const char *label, int dpdnum);
 struct dpd_file2_cache_entry *dpd_file2_cache_last(void);
 int dpd_file2_cache_add(dpdfile2 *File);
 int dpd_file2_cache_del(dpdfile2 *File);
+int dpd_file4_cache_del_low(void);
+void dpd_file2_cache_dirty(dpdfile2 *File);
 
 void dpd_file4_cache_init(void);
 void dpd_file4_cache_close(void);
 void dpd_file4_cache_print(FILE *outfile);
 void dpd_file4_cache_print_screen(void);
+int dpd_file4_cache_get_priority(dpdfile4 *File);
+
 struct dpd_file4_cache_entry
- *dpd_file4_cache_scan(int filenum, int irrep, int pqnum, int rsnum, char *label, int dpdnum);
+ *dpd_file4_cache_scan(int filenum, int irrep, int pqnum, int rsnum, const char *label, int dpdnum);
 struct dpd_file4_cache_entry *dpd_file4_cache_last(void);
 int dpd_file4_cache_add(dpdfile4 *File, unsigned int priority);
 int dpd_file4_cache_del(dpdfile4 *File);
@@ -378,7 +391,7 @@ void cc3_sigma_RHF_ic(dpdbuf4 *CIjAb, dpdbuf4 *WAbEi, dpdbuf4 *WMbIj,
     int do_singles, dpdbuf4 *Dints, dpdfile2 *SIA,
     int do_doubles, dpdfile2 *FME, dpdbuf4 *WAmEf, dpdbuf4 *WMnIe,
     dpdbuf4 *SIjAb, int *occpi, int *occ_off, int *virtpi, int *vir_off,
-    double omega, FILE *outfile);
+    double omega, FILE *outfile, int nthreads);
 
 void cc3_sigma_UHF_AAA(dpdbuf4 *CMNEF, dpdbuf4 *WABEI, dpdbuf4 *WMBIJ,
     int do_singles, dpdbuf4 *Dints_anti, dpdfile2 *SIA, int do_doubles,
@@ -414,5 +427,9 @@ void cc3_sigma_UHF_BBA(dpdbuf4 *C2BB, dpdbuf4 *C2AB, dpdbuf4 *C2BA,
     int *bocc_off, int *avirtpi, int *avir_off, int *bvirtpi, int *bvir_off,
     double omega, FILE *outfile);
 
-#endif /* DPD_H */
+#ifdef __cplusplus
+} /* extern "C" */
+#endif
+
+#endif /* _psi_src_lib_libdpd_dpd_h */
 
