@@ -1,3 +1,10 @@
+/*! \file
+    \ingroup IPV1
+    \brief Enter brief description of file here 
+*/
+
+#ifndef _psi_src_lib_libipv1_iplib_h_
+#define _psi_src_lib_libipv1_iplib_h_
 
 #include <libipv1/tmpl.h>
 #include <libipv1/ip_types.h>
@@ -9,3 +16,4 @@
 #include <libipv1/ip_print.gbl>
 #include <libipv1/ip_read.gbl>
 
+#endif /* header guard */
