@@ -1,7 +1,7 @@
-/*
-** qt.h
-**
-** Header file for the Quantum Trio Library 
+/*!
+** \file
+** \brief Header file for the Quantum Trio Library 
+** \ingroup QT
 **
 ** David Sherrill 1994
 **
@@ -11,6 +11,12 @@
 #ifndef _psi_src_lib_libqt_qt_h_
 #define _psi_src_lib_libqt_qt_h_
 
+#include <cstdio>
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int mat_in(FILE *fp, double **array, int width, int max_length, int *stat);
 void fill_sym_matrix(double **A, int size);
 double combinations(int n, int k);
@@ -59,28 +65,28 @@ double eri(unsigned int l1, unsigned int m1, unsigned int n1,
 double norm_const(unsigned int l1, unsigned int m1, unsigned int n1, 
         double alpha1, double A[3]);
 
-extern void C_DAXPY(int length, double a, double *x, int inc_x,
+void C_DAXPY(int length, double a, double *x, int inc_x,
              double *y, int inc_y);
-extern void C_DCOPY(int length, double *x, int inc_x,
+void C_DCOPY(int length, double *x, int inc_x,
              double *y, int inc_y);
-extern void C_DGEMM(char transa, char transb, int m, int n, int k,
+void C_DGEMM(char transa, char transb, int m, int n, int k,
              double alpha, double *A, int nca, double *B, int ncb,
              double beta, double *C, int ncc);
-extern void C_DROT(int ntot, double *x, int incx, double *y, int incy,
+void C_DROT(int ntot, double *x, int incx, double *y, int incy,
              double costheta, double sintheta);
-extern void C_DSCAL(long int len, double alpha, double *vec, int inc);
-extern void C_DGEMV(char transa, int m, int n, double alpha, double *A, 
+void C_DSCAL(long int len, double alpha, double *vec, int inc);
+void C_DGEMV(char transa, int m, int n, double alpha, double *A, 
              int nca, double *X, int inc_x, double beta, double *Y,
              int inc_y);
-extern void C_DSPMV(char uplo, int n, double alpha, double *A,
+void C_DSPMV(char uplo, int n, double alpha, double *A,
              double *X, int inc_x, double beta, double *Y,
              int inc_y);
-extern double C_DDOT(int n, double *X, int inc_x, double *Y, int inc_y);
-extern int C_DGETRF(int nrow, int ncol, double *a, int lda, int *ipiv);
+double C_DDOT(int n, double *X, int inc_x, double *Y, int inc_y);
+int C_DGETRF(int nrow, int ncol, double *a, int lda, int *ipiv);
 void timer_init(void);
 void timer_done(void);
-void timer_on(char *key);
-void timer_off(char *key);
+void timer_on(const char *key);
+void timer_off(const char *key);
 
 void filter(double *input, double *output, int *ioff, int norbs, int nfzc, 
       int nfzv);
@@ -99,6 +105,7 @@ int C_DSYEV(char jobz, char uplo, int n, double *A, int lda, double *w,
 void print_block(double *, int, int, FILE *);
 
 void sort(double *A, double **B, int n);
+void sort_vector(double *A, int n);
 
 int david(double **A, int N, int M, double *eps, double **v, double cutoff, 
      int print);
@@ -110,7 +117,27 @@ int cc_wfn(char *wfn);
 void free_3d_array(double ***A, int p, int q);
 double ***init_3d_array(int p, int q, int r);
 int ci_wfn(char *wfn);
+void orient_fragment(int natom_A, int natom_B, int P_A, int P_B, double **geom_A, double **geom_B,
+  double **ref_coeff_A, double **ref_coeff_B, double R_AB, double theta_A, double theta_B,
+  double tau, double phi_A, double phi_B, FILE *outfile);
+void zmat_point(double *A, double *B, double *C, double R_CD, double theta_BCD, double phi_ABCD, double *D);
+void rotate_vecs(double *axis, double phi, double **vectors, int num_vectors);
+double dot_prod(double *v1, double *v2);
+void cross_prod(double *v1, double *v2, double *out);
+void unit_vec(double *B, double *A, double *AB);
 
 #define MAX_RAS_SPACES 4
 
+#ifdef __cplusplus
+}
 #endif
+
+/* Some functions should not be used outside of Psi */
+#ifdef __cplusplus
+namespace psi {
+  /// Same as ::strncpy(), but make sure that dest ends in \0
+  char* strncpy(char* dest, const char* source, size_t n);
+}
+#endif
+
+#endif /* _psi_src_lib_libqt_qt_h */
