@@ -1,3 +1,10 @@
+/*! \file
+    \ingroup R12
+    \brief Enter brief description of file here 
+*/
+
+/*! \defgroup R12 libr12: The R12 Library */
+
 /*---------------------------------------------------------------------------------------------
   This code generates Level 0 and 1 routines for computing non-standard two-electron integrals
   necessary in linear R12-methods. Evaluation is performed in Cartesian environment
