@@ -5,10 +5,13 @@
 
 #
 # Rules of use:
-# 1) environment must define variable $SRCDIR which points to the source directory where
-#    the input and reference output files are located
-# 2) variable $EXECDIR can be used to specify location of Psi3 executables relative to the directory
-#    where testing is performed
+# 1) environment must define variable $SRCDIR which points to the source 
+#    directory where the input and reference output files are located
+# 2) variable $EXECDIR can be used to specify location of Psi3 executables 
+#    relative to the directory where testing is performed
+#
+# Escape metacharacters in wavefunction match string for file11
+# to enable wfn=SCF+D --- CDS 3/20/08
 #
 
 #
@@ -36,12 +39,15 @@ if ($PSITEST_PREFIX eq "") {
 $PSITEST_TARGET_SUFFIX = "test";
 $PSITEST_TEST_SCRIPT = "runtest.pl";
 
-# These are definitions that default tester knows about -- should match Psi driver!
+$PSITEST_SUMMARY_FILE = "../../test-case-results";
+
+# definitions that default tester knows about -- should match Psi driver!
 @PSITEST_JOBTYPES = ("SP", "OPT", "DISP", "FREQ", "SYMM_FC", "FC", 
 "OEPROP", "DBOC");
 @PSITEST_WFNS = ("SCF", "MP2", "MP2R12", "DETCI", "DETCAS", "CASSCF",
-"RASSCF", "BCCD", "BCCD_T", "CC2", "CCSD", "CCSD_T", "CC3", "EOM_CC2", 
-"LEOM_CC2", "EOM_CCSD", "LEOM_CCSD", "OOCCD", "CIS", "EOM_CC3");
+"RASSCF", "ZAPTN", "BCCD", "BCCD_T", "CC2", "CCSD", "CCSD_T", "CC3", 
+"EOM_CC2", "LEOM_CC2", "EOM_CCSD", "LEOM_CCSD", "OOCCD", "CIS", "EOM_CC3",
+"SCF_MVD","PSIMRCC","SCF+D","MCSCF","IDMKPT2");
 @PSITEST_REFTYPES = ("RHF", "ROHF", "UHF", "TWOCON");
 @PSITEST_DERTYPES = ("NONE", "FIRST", "SECOND", "RESPONSE");
 
@@ -52,12 +58,14 @@ $PSITEST_ENUCTOL = 10**-13;       # Check nuclear repulsion energy tighter than
 $PSITEST_EEOMTOL = 10**-5;        # Less stringent test for EOM-CC energies
 $PSITEST_GEOMTOL = 10**-6;        # Default test criterion for Cartesian geometries
 $PSITEST_GTOL = 10**-6;           # Default test criterion for gradients
-$PSITEST_HTOL = 10**-2;           # Default test criterion for Hessians
+$PSITEST_HTOL = 10**-1;           # Default test criterion for Hessians
 $PSITEST_POLARTOL = 10**-5;       # Default test criterion for polarizabilities
 $PSITEST_OPTROTTOL = 10**-3;      # Default test criterion for optical rotation
 $PSITEST_STABTOL = 10**-4;        # Default test criterion for Hessian eigenvalues
 $PSITEST_MPOPTOL = 10**-5;        # Default test criterion for Mulliken populations
 $PSITEST_CIDIPTOL = 10**-4;       # Default test criterion for CI dipoles
+$PSITEST_STRICT_ETOL = 10**-12;      # Strict  test criterion for energies
+$PSIMRCCTEST_ETOL = 10**-10;      # Default test criterion for PSIMRCC energies
 ##################################################
 #
 # This is a "smart" tester -- it parses the input and figures out
@@ -161,13 +169,16 @@ sub do_tests
           if ($wfn eq "CASSCF")   { $fail |= compare_casscf_energy(); last SWITCH2; }
           if ($wfn eq "RASSCF")   { $fail |= compare_rasscf_energy(); last SWITCH2; }
           if ($wfn eq "DETCI")    { $fail |= compare_ci_energy(); last SWITCH2; }
+          if ($wfn eq "ZAPTN")    { $fail |= compare_zaptn_energy(); last SWITCH2; }
           if ($wfn eq "CIS")      { $fail |= compare_cis_energy(); last SWITCH2; }
           if ($wfn eq "MP2" && $direct == 1)
                                   { $fail |= compare_direct_mp2_energy(); last SWITCH2; }
           if ($wfn eq "MP2" && $direct == 0)
                                   { $fail |= compare_mp2_energy(); last SWITCH2; }
           if ($wfn eq "MP2R12")   { $fail |= compare_mp2r12_energy(); last SWITCH2; }
-
+          if ($wfn eq "PSIMRCC")  { $fail |= compare_psimrcc_energy(); last SWITCH2; }
+          if ($wfn eq "IDMKPT2")  { $fail |= compare_psimrcc_energy(); last SWITCH2; }
+          if ($wfn eq "SCF+D")  { $fail |= compare_scf_d_energy(); last SWITCH2; }
       }
       
       if ($jobtype eq "SP" && $dertype eq "FIRST") {
@@ -293,6 +304,7 @@ sub test_finished
   $target = "$test_name.$PSITEST_TARGET_SUFFIX";
 
   system("cat $target");
+  system("cat $target >> $PSITEST_SUMMARY_FILE");
 
   if ($interrupted) {
     exit($fail);
@@ -762,6 +774,23 @@ sub compare_ci_energy
   return $fail;
 }
 
+sub compare_zaptn_energy
+{
+  my $fail = 0;
+  my $REF_FILE = "$SRC_PATH/output.ref";
+  my $TEST_FILE = "output.dat";
+
+  if(abs(seek_zaptn($REF_FILE) - seek_zaptn($TEST_FILE)) > $PSITEST_ETOL) {
+    fail_test("ZAPTn energy"); $fail = 1;
+  }
+  else {
+    pass_test("ZAPTn energy");
+  }
+
+  return $fail;
+}
+
+
 sub dip_check
 {
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
@@ -842,7 +871,7 @@ sub scs_check
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   seek(OUT,0,0);
   while(<OUT>) {
-    if (/SCS\s+=\s+TRUE/) {
+    if (/\s+SCS\s+=\s+True/) {
       close(OUT);
       return 1;
     }
@@ -1264,6 +1293,43 @@ sub compare_pair_energies
   return $fail;
 }
 
+sub compare_psimrcc_energy
+{
+  my $fail = 0;
+  my $REF_FILE = "$SRC_PATH/output.ref";
+  my $TEST_FILE = "output.dat";
+
+  if(abs(seek_psimrcc($REF_FILE) - seek_psimrcc($TEST_FILE)) > $PSIMRCCTEST_ETOL) {
+    fail_test("PSIMRCC energy"); $fail = 1;
+  }
+  else {
+    pass_test("PSIMRCC energy");
+  }
+
+#  printf("\nseek = %lf",seek_psimrcc($TEST_FILE));  
+
+  return $fail;
+}
+
+sub compare_scf_d_energy
+{
+  my $fail = 0;
+  my $REF_FILE = "$SRC_PATH/output.ref";
+  my $TEST_FILE = "output.dat";
+
+  if(abs(seek_scf_d($REF_FILE) - seek_scf_d($TEST_FILE)) > $PSITEST_ETOL) {
+    fail_test("SCF+D energy"); $fail = 1;
+  }
+  else {
+    pass_test("SCF+D energy");
+  }
+  
+  return $fail;
+}
+
+
+
+
 sub seek_nirreps
 {
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
@@ -1362,7 +1428,7 @@ sub seek_scf
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   seek(OUT,0,0);
   while(<OUT>) {
-    if (/SCF total energy/) {
+    if (/\* SCF total energy/) {
       @data = split(/ +/, $_);
       $scf = $data[5];
       return $scf;
@@ -1374,14 +1440,30 @@ sub seek_scf
   exit 1;
 }
 
+sub seek_scf_d
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  seek(OUT,0,0);
+  while(<OUT>) {
+    if (/\* Total energy \+ empirical/) {
+      @data = split(/ =\s+/, $_);
+      ($scf,$junk) = split(/ /, $data[1]);
+      return $scf;
+    }
+  }
+  close(OUT);
+
+  printf "Error: Could not find SCF+D energy in $_[0].\n";
+  exit 1;
+}
+
 sub seek_mp2
 {
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   seek(OUT,0,0);
   while(<OUT>) {
-    if (/\s+MP2 total energy/) {
-      @data = split(/ +/, $_);
-      $mp2 = $data[4];
+    if (/\s+\* MP2 total energy/) {
+      ($junk,$mp2) = split(/=\s+/, $_);
       return $mp2;
     }
   }
@@ -1413,9 +1495,8 @@ sub seek_scs_mp2
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   seek(OUT,0,0);
   while(<OUT>) {
-    if (/SCS-MP2 total energy/) {
-      @data = split(/ +/, $_);
-      $scs_mp2 = $data[4];
+    if (/\s+\* SCS-MP2 total energy/) {
+      ($junk,$scs_mp2) = split(/=\s+/, $_);
       return $scs_mp2;
     }
   }
@@ -1465,9 +1546,8 @@ sub seek_cc2
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   seek(OUT,0,0);
   while(<OUT>) {
-    if (/Total CC2 energy/) {
-      @data = split(/ +/, $_);
-      $cc2 = $data[4];
+    if (/\* CC2 total energy/) {
+      ($junk, $cc2) = split(/=\s+/, $_);
       return $cc2;
     }
   }
@@ -1482,9 +1562,8 @@ sub seek_ccsd
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   seek(OUT,0,0);
   while(<OUT>) {
-    if (/Total CCSD energy/) {
-      @data = split(/ +/, $_);
-      $ccsd = $data[4];
+    if (/\* CCSD total energy/) {
+      ($junk, $ccsd) = split(/=\s+/, $_);
       return $ccsd;
     }
   }
@@ -1499,9 +1578,8 @@ sub seek_ccsd_t
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   seek(OUT,0,0);
   while(<OUT>) {
-    if (/Total CCSD\(T\) energy/) {
-      @data = split(/ +/, $_);
-      $ccsd_t = $data[4];
+    if (/\* CCSD\(T\) total energy/) {
+      ($junk, $ccsd_t) = split(/=\s+/, $_);
       return $ccsd_t;
     }
   }
@@ -1516,9 +1594,8 @@ sub seek_cc3
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   seek(OUT,0,0);
   while(<OUT>) {
-    if (/Total CC3 energy/) {
-      @data = split(/ +/, $_);
-      $ccsd = $data[4];
+    if (/\* CC3 total energy/) {
+      ($junk, $ccsd) = split(/=\s+/, $_);
       return $ccsd;
     }
   }
@@ -1534,7 +1611,7 @@ sub seek_bccd
   @datafile = <OUT>;
   close(OUT);
 
-  $match = "Total CCSD energy";
+  $match = "\* CCSD total energy";
   $linenum = 0;
   $lastiter = 0;
 
@@ -1545,8 +1622,7 @@ sub seek_bccd
     $linenum++;
   }
 
-  @line = split (/ +/, $datafile[$lastiter]);
-  $bccd = $line[5];
+  ($junk, $bccd) = split (/=\s+/, $datafile[$lastiter]);
 
   if($bccd != 0.0) {
     return $bccd;
@@ -1579,9 +1655,8 @@ sub seek_casscf
 
 #Added to handle David's new CASSCF output format
   while (<OUT>) {
-      if (/Final CASSCF Energy/) {
-	  @data = split(/=/, $_);
-	  $casscf = $data[2];
+      if (/\* CASSCF total energy/) {
+	  ($junk,$casscf) = split(/=\s+/, $_);
 	  return $casscf;
       }
   }
@@ -1596,9 +1671,8 @@ sub seek_rasscf
 
 #Added to handle David's new RASSCF output format
   while (<OUT>) {
-      if (/Final RASSCF Energy/) {
-	  @data = split(/=/, $_);
-	  $casscf = $data[2];
+      if (/\* RASSCF total energy/) {
+          ($junk,$casscf) = split(/=\s+/, $_);
 	  return $casscf;
       }
   }
@@ -1612,9 +1686,9 @@ sub seek_ci
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   seek(OUT,0,0);
   while (<OUT>) {
-    if (/ROOT 1/) {
-    @data = split(/ +/, $_);
-    $ci = $data[4];
+    if (/\* ROOT 1 CI total energy/) {
+    @data = split(/=\s+/, $_);
+    ($ci,$junk) = split(/ /, $data[1]);
     }
   }
 
@@ -1625,14 +1699,34 @@ sub seek_ci
   printf "Error: Could not find CI energy in $_[0].\n";
   exit 1;
 }
-			  
+
+sub seek_zaptn
+{
+  my $zaptn;
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  seek(OUT,0,0);
+  while (<OUT>) {
+    if (/EZAPTn/) {
+    @data = split(/ +/, $_);
+    $zaptn = $data[2];
+    }
+  }
+
+  if($zaptn != 0.0) {
+    return $zaptn;
+  }
+
+  printf "Error: Could not find ZAPTn energy in $_[0].\n";
+  exit 1;
+}
+
 sub seek_energy_file11
 {
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   @datafile = <OUT>;
   close(OUT);
 
-  $match = "$_[1]";
+  $match = quotemeta($_[1]);
   $linenum = 0;
   $lasiter = 0;
 
@@ -1660,7 +1754,7 @@ sub seek_natom_file11
   @datafile = <OUT>;
   close(OUT);
 
-  $match = "$_[1]";
+  $match = quotemeta($_[1]);
   $linenum = 0;
   $lasiter = 0;
 
@@ -1688,7 +1782,7 @@ sub seek_geom_file11
   @datafile = <OUT>;
   close(OUT);
 
-  $match = "$_[1]";
+  $match = quotemeta($_[1]);
   $linenum = 0;
   $lasiter = 0;
   $foundit = 0;
@@ -1725,7 +1819,7 @@ sub seek_grad_file11
   @datafile = <OUT>;
   close(OUT);
 
-  $match = "$_[1]";
+  $match = quotemeta($_[1]);
   $linenum = 0;
   $lasiter = 0;
   $foundit = 0;
@@ -2577,6 +2671,29 @@ sub seek_rot_str
   exit 1;
 }
 
+sub seek_psimrcc
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  seek(OUT,0,0);
+  while(<OUT>) {
+    if (/\* MK-MRCCSD total energy/) {
+      @data = split(/ +/, $_);
+      $psimrcc = $data[5];
+      return $psimrcc;
+    }
+    if (/\* MK-MRPT2 total energy/) {
+      @data = split(/ +/, $_);
+      $psimrcc = $data[5];
+      return $psimrcc;
+    }
+  }
+  close(OUT);
+
+  printf "Error: Could not find PSIMRCC energy in $_[0].\n";
+  exit 1;
+}
+
+
 sub compare_arrays
 {
   my $A = $_[0];
